@@ -1,6 +1,3 @@
-import os
-from pathlib import Path
-
 import numpy as np
 import specutils
 from astropy import units as u
@@ -20,15 +17,13 @@ from jdaviz.core.template_mixin import (PluginTemplateMixin,
                                         SpectralContinuumMixin,
                                         skip_if_no_updates_since_last_active,
                                         with_spinner)
+from jdaviz.core.unit_conversion_utils import convert_integrated_sb_unit
 from jdaviz.core.user_api import PluginUserApi
 
 __all__ = ['MomentMap']
 
 SPECUTILS_LT_1_15_1 = not minversion(specutils, "1.15.1.dev")
 
-spaxel = u.def_unit('spaxel', 1 * u.Unit(""))
-u.add_enabled_units([spaxel])
-
 moment_unit_options = {0: ["Surface Brightness"],
                        1: ["Velocity", "Spectral Unit"],
                        2: ["Velocity", "Velocity^N"]}
@@ -80,7 +75,6 @@ class MomentMap(PluginTemplateMixin, DatasetSelectMixin, SpectralSubsetSelectMix
     n_moment = IntHandleEmpty(0).tag(sync=True)
     filename = Unicode().tag(sync=True)
     moment_available = Bool(False).tag(sync=True)
-    overwrite_warn = Bool(False).tag(sync=True)
     output_unit_items = List().tag(sync=True)
     output_radio_items = List().tag(sync=True)
     output_unit_selected = Unicode().tag(sync=True)
@@ -95,6 +89,9 @@ class MomentMap(PluginTemplateMixin, DatasetSelectMixin, SpectralSubsetSelectMix
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
+        # description displayed under plugin title in tray
+        self._plugin_description = 'Create a 2D image from a data cube.'
+
         self.moment = None
 
         self.continuum_dataset = DatasetSelect(self,
@@ -325,7 +322,40 @@ class MomentMap(PluginTemplateMixin, DatasetSelectMixin, SpectralSubsetSelectMix
         # convert units for moment 0, which is the only currently supported
         # moment for using converted units.
         if n_moment == 0:
-            self.moment = self.moment.to(self.moment_zero_unit)
+            if self.moment_zero_unit != self.moment.unit:
+                spectral_axis_unit = u.Unit(self.spectrum_viewer.state.x_display_unit)
+
+                # if the flux unit is a per-frequency unit but the spectral axis unit
+                # is a wavelength, or vice versa, we need to convert the spectral axis
+                # unit that the flux was integrated over so they are compatible for
+                # unit conversion (e.g., Jy m / sr needs to become Jy Hz / sr, and
+                # (erg Hz)/(s * cm**2 * AA) needs to become (erg)/(s * cm**2)
+                desired_freq_unit = spectral_axis_unit if spectral_axis_unit.physical_type == 'frequency' else u.Hz  # noqa E501
+                desired_length_unit = spectral_axis_unit if spectral_axis_unit.physical_type == 'length' else u.AA  # noqa E501
+                moment_temp = convert_integrated_sb_unit(self.moment,
+                                                         spectral_axis_unit,
+                                                         desired_freq_unit,
+                                                         desired_length_unit)
+                moment_zero_unit_temp = convert_integrated_sb_unit(1 * u.Unit(self.moment_zero_unit),  # noqa E501
+                                                                   spectral_axis_unit,
+                                                                   desired_freq_unit,
+                                                                   desired_length_unit)
+
+                moment = moment_temp.to(moment_zero_unit_temp.unit, u.spectral())
+
+                # if flux and spectral axis units were incompatible in terms of freq/wav
+                # and needed to be converted to an intermediate unit for conversion, then
+                # re-instate the original chosen units (e.g Jy m /sr was converted to Jy Hz / sr
+                # for unit conversion, now back to Jy m / sr)
+                if spectral_axis_unit not in moment.unit.bases:
+                    if spectral_axis_unit.physical_type == 'frequency':
+                        moment *= (1*desired_length_unit).to(desired_freq_unit,
+                                                             u.spectral()) / desired_length_unit
+                    elif spectral_axis_unit.physical_type == 'length':
+                        moment *= (1*desired_freq_unit).to(desired_length_unit,
+                                                           u.spectral()) / desired_freq_unit
+
+                self.moment = moment
 
         # Reattach the WCS so we can load the result
         self.moment = CCDData(self.moment, wcs=data_wcs)
@@ -349,9 +379,9 @@ class MomentMap(PluginTemplateMixin, DatasetSelectMixin, SpectralSubsetSelectMix
         if self.spectrum_viewer.state.x_display_unit is not None:
             return (
                 u.Unit(self.app._get_display_unit('sb')) *
-                self.spectrum_viewer.state.x_display_unit
+                u.Unit(self.spectrum_viewer.state.x_display_unit)
             )
-        return ''
+        return u.dimensionless_unscaled
 
     @property
     def spectral_unit_selected(self):
@@ -360,45 +390,6 @@ class MomentMap(PluginTemplateMixin, DatasetSelectMixin, SpectralSubsetSelectMix
     def vue_calculate_moment(self, *args):
         self.calculate_moment(add_data=True)
 
-    def vue_save_as_fits(self, *args):
-        self._write_moment_to_fits()
-
     def vue_overwrite_fits(self, *args):
         """Attempt to force writing the moment map if the user confirms the desire to overwrite."""
         self.overwrite_warn = False
-        self._write_moment_to_fits(overwrite=True)
-
-    def _write_moment_to_fits(self, overwrite=False, *args):
-        if self.moment is None or not self.filename:  # pragma: no cover
-            return
-        if not self.export_enabled:
-            # this should never be triggered since this is intended for UI-disabling and the
-            # UI section is hidden, but would prevent any JS-hacking
-            raise ValueError("Writing out moment map to file is currently disabled")
-
-        # Make sure file does not end up in weird places in standalone mode.
-        path = os.path.dirname(self.filename)
-        if path and not os.path.exists(path):
-            raise ValueError(f"Invalid path={path}")
-        elif (not path or path.startswith("..")) and os.environ.get("JDAVIZ_START_DIR", ""):  # noqa: E501 # pragma: no cover
-            filename = Path(os.environ["JDAVIZ_START_DIR"]) / self.filename
-        else:
-            filename = Path(self.filename).resolve()
-
-        if filename.exists():
-            if overwrite:
-                # Try to delete the file
-                filename.unlink()
-                if filename.exists():
-                    # Warn the user if the file still exists
-                    raise FileExistsError(f"Unable to delete {filename}. Check user permissions.")
-            else:
-                self.overwrite_warn = True
-                return
-
-        filename = str(filename)
-        self.moment.write(filename)
-
-        # Let the user know where we saved the file.
-        self.hub.broadcast(SnackbarMessage(
-            f"Moment map saved to {os.path.abspath(filename)}", sender=self, color="success"))
