@@ -1,6 +1,4 @@
-import os
 from functools import cached_property
-from pathlib import Path
 
 import numpy as np
 import astropy
@@ -22,10 +20,11 @@ from jdaviz.core.template_mixin import (PluginTemplateMixin,
                                         skip_if_no_updates_since_last_active,
                                         with_spinner, with_temp_disable)
 from jdaviz.core.user_api import PluginUserApi
-from jdaviz.core.validunits import check_if_unit_is_per_solid_angle
+from jdaviz.core.unit_conversion_utils import (all_flux_unit_conversion_equivs,
+                                               flux_conversion_general,
+                                               check_if_unit_is_per_solid_angle)
 from jdaviz.configs.cubeviz.plugins.parsers import _return_spectrum_with_correct_units
 from jdaviz.configs.cubeviz.plugins.viewers import WithSliceIndicator
-from jdaviz.utils import _eqv_pixar_sr
 
 
 __all__ = ['SpectralExtraction']
@@ -105,7 +104,6 @@ class SpectralExtraction(PluginTemplateMixin, ApertureSubsetSelectMixin,
     function_selected = Unicode('Sum').tag(sync=True)
     filename = Unicode().tag(sync=True)
     extraction_available = Bool(False).tag(sync=True)
-    overwrite_warn = Bool(False).tag(sync=True)
 
     results_units = Unicode().tag(sync=True)
     spectrum_y_units = Unicode().tag(sync=True)
@@ -127,6 +125,9 @@ class SpectralExtraction(PluginTemplateMixin, ApertureSubsetSelectMixin,
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
+        # description displayed under plugin title in tray
+        self._plugin_description = 'Extract a spectrum from a spectral cube.'
+
         self.extracted_spec = None
 
         self.dataset.filters = ['is_flux_cube']
@@ -576,7 +577,7 @@ class SpectralExtraction(PluginTemplateMixin, ApertureSubsetSelectMixin,
         uncertainty = collapsed_nddata.uncertainty
 
         collapsed_spec = _return_spectrum_with_correct_units(
-            flux, wcs, collapsed_nddata.meta, 'flux',
+            flux, wcs, collapsed_nddata.meta, data_type='flux',
             target_wave_unit=target_wave_unit,
             uncertainty=uncertainty,
             mask=mask
@@ -587,9 +588,20 @@ class SpectralExtraction(PluginTemplateMixin, ApertureSubsetSelectMixin,
         return extracted.spectral_axis
 
     def _preview_y_from_extracted(self, extracted):
-        # TODO: use extracted.meta.get('PIXAR_SR') once populated
-        return extracted.flux.to(self.spectrum_y_units,
-                                 equivalencies=_eqv_pixar_sr(self.dataset.selected_obj.meta.get('PIXAR_SR', 1.0)))  # noqa:
+        """
+        Convert y-axis units of extraction preview to display units,
+        if necessary.
+        """
+
+        if extracted.flux.unit != self.spectrum_y_units:
+
+            eqv = all_flux_unit_conversion_equivs(self.dataset.selected_obj.meta.get('PIXAR_SR', 1.0),  # noqa
+                                                  self.dataset.selected_obj.spectral_axis)
+
+            return flux_conversion_general(extracted.flux.value, extracted.flux.unit,
+                                           self.spectrum_y_units, eqv)
+
+        return extracted.flux
 
     @with_spinner()
     def extract(self, return_bg=False, add_data=True, **kwargs):
@@ -697,50 +709,6 @@ class SpectralExtraction(PluginTemplateMixin, ApertureSubsetSelectMixin,
     def vue_create_bg_spec(self, *args, **kwargs):
         self.extract_bg_spectrum(add_data=True)
 
-    def vue_save_as_fits(self, *args):
-        self._save_extracted_spec_to_fits()
-
-    def vue_overwrite_fits(self, *args):
-        """Attempt to force writing the spectral extraction if the user
-        confirms the desire to overwrite."""
-        self.overwrite_warn = False
-        self._save_extracted_spec_to_fits(overwrite=True)
-
-    def _save_extracted_spec_to_fits(self, overwrite=False, *args):
-
-        if not self.export_enabled:
-            # this should never be triggered since this is intended for UI-disabling and the
-            # UI section is hidden, but would prevent any JS-hacking
-            raise ValueError(f"Writing out extracted {self.resulting_product_name} to file is currently disabled")  # noqa
-
-        # Make sure file does not end up in weird places in standalone mode.
-        path = os.path.dirname(self.filename)
-        if path and not os.path.exists(path):
-            raise ValueError(f"Invalid path={path}")
-        elif (not path or path.startswith("..")) and os.environ.get("JDAVIZ_START_DIR", ""):  # noqa: E501 # pragma: no cover
-            filename = Path(os.environ["JDAVIZ_START_DIR"]) / self.filename
-        else:
-            filename = Path(self.filename).resolve()
-
-        if filename.exists():
-            if overwrite:
-                # Try to delete the file
-                filename.unlink()
-                if filename.exists():
-                    # Warn the user if the file still exists
-                    raise FileExistsError(f"Unable to delete {filename}. Check user permissions.")
-            else:
-                self.overwrite_warn = True
-                return
-
-        filename = str(filename)
-        self.extracted_spec.write(filename)
-
-        # Let the user know where we saved the file.
-        self.hub.broadcast(SnackbarMessage(
-            f"Extracted {self.resulting_product_name} saved to {os.path.abspath(filename)}",
-            sender=self, color="success"))
-
     @observe('aperture_selected', 'function_selected')
     def _set_default_results_label(self, event={}):
         if not hasattr(self, 'aperture'):
