@@ -8,6 +8,7 @@ from specutils import Spectrum1D, SpectralRegion
 from glue_astronomy.translators.spectrum1d import PaddedSpectrumWCS
 from numpy.testing import assert_allclose, assert_array_equal
 
+from jdaviz.core.custom_units_and_equivs import PIX2
 from jdaviz.utils import PRIHDR_KEY
 
 
@@ -73,8 +74,8 @@ def test_spectrum1d_with_fake_fixed_units(spectrum1d, cubeviz_helper):
 
     cubeviz_helper.app.add_data_to_viewer('spectrum-viewer', 'test')
     unit = u.Unit(cubeviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
-    cubeviz_helper.plugins['Subset Tools']._obj.import_region(SpectralRegion(6600 * unit,
-                                                                             7400 * unit))
+    cubeviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(6600 * unit,
+                                                                        7400 * unit))
 
     subsets = cubeviz_helper.app.get_subsets()
     reg = subsets.get('Subset 1')
@@ -149,8 +150,9 @@ def test_spectrum3d_parse(image_cube_hdu_obj, cubeviz_helper):
     assert label_mouseover.as_text() == ('', '', '')
 
 
-def test_spectrum3d_no_wcs_parse(cubeviz_helper):
-    sc = Spectrum1D(flux=np.ones(24).reshape((2, 3, 4)) * u.nJy)  # x, y, z
+@pytest.mark.parametrize("flux_unit", [u.nJy, u.DN, u.DN / u.s])
+def test_spectrum3d_no_wcs_parse(cubeviz_helper, flux_unit):
+    sc = Spectrum1D(flux=np.ones(24).reshape((2, 3, 4)) * flux_unit)  # x, y, z
     cubeviz_helper.load_data(sc)
     assert sc.spectral_axis.unit == u.pix
 
@@ -160,7 +162,7 @@ def test_spectrum3d_no_wcs_parse(cubeviz_helper):
     assert data.shape == (2, 3, 4)  # x, y, z
     assert isinstance(data.coords, PaddedSpectrumWCS)
     assert_array_equal(flux.data, 1)
-    assert flux.units == 'nJy / pix2'
+    assert flux.units == f'{flux_unit / PIX2}'
 
 
 def test_spectrum1d_parse(spectrum1d, cubeviz_helper):
@@ -196,7 +198,7 @@ def test_numpy_cube(cubeviz_helper):
     assert data.label == 'Array'
     assert data.shape == (4, 3, 2)  # x, y, z
     assert isinstance(data.coords, PaddedSpectrumWCS)
-    assert flux.units == 'ct'
+    assert flux.units == 'ct / pix2'
 
     # Check context of second cube.
     data = cubeviz_helper.app.data_collection[1]
@@ -204,7 +206,7 @@ def test_numpy_cube(cubeviz_helper):
     assert data.label == 'uncert_array'
     assert data.shape == (4, 3, 2)  # x, y, z
     assert isinstance(data.coords, PaddedSpectrumWCS)
-    assert flux.units == 'ct'
+    assert flux.units == 'ct / pix2'
 
 
 def test_loading_with_mask(cubeviz_helper):
@@ -248,7 +250,7 @@ def test_manga_with_mask(cubeviz_helper, function, expected_value):
     se.function = function
     se.extract()
     extracted_max = cubeviz_helper.get_data(f"Spectrum ({function.lower()})").max()
-    assert_allclose(extracted_max.value, expected_value, rtol=5e-6)
+    assert_allclose(extracted_max.value, expected_value, rtol=5e-7)
     if function == "Sum":
         assert extracted_max.unit == u.Unit("erg / Angstrom s cm**2")
     else:
