@@ -29,7 +29,7 @@ class TestLoadRegions(BaseRegionHandler):
     def test_regions_mask(self):
         mask = np.zeros((9, 10), dtype=np.bool_)
         mask[0, 0] = True
-        bad_regions = self.cubeviz.plugins['Subset Tools']._obj.import_region(
+        bad_regions = self.cubeviz.plugins['Subset Tools'].import_region(
             [mask], return_bad_regions=True)
 
         # TODO: Update expected results if we ever support masked Subset in Cubeviz.
@@ -38,16 +38,16 @@ class TestLoadRegions(BaseRegionHandler):
     def test_regions_pixel(self):
         # A little out-of-bounds should still overlay the overlapped part.
         my_reg = CirclePixelRegion(center=PixCoord(x=6, y=2), radius=5)
-        bad_regions = self.cubeviz.plugins['Subset Tools']._obj.import_region(
+        bad_regions = self.cubeviz.plugins['Subset Tools'].import_region(
             [my_reg], return_bad_regions=True)
         assert len(bad_regions) == 0
         self.verify_region_loaded('Subset 1', count=1)
-        assert len(self.cubeviz.get_interactive_regions()) == 1
+        assert len(self.cubeviz.plugins['Subset Tools'].get_regions()) == 1
 
     def test_regions_sky_has_wcs(self):
         sky = SkyCoord(205.4397, 27.0035, unit='deg')
         my_reg_sky_1 = CircleSkyRegion(center=sky, radius=0.0004 * u.deg)
-        bad_regions = self.cubeviz.plugins['Subset Tools']._obj.import_region(
+        bad_regions = self.cubeviz.plugins['Subset Tools'].import_region(
             my_reg_sky_1, return_bad_regions=True)
 
         # TODO: Update expected results when we support sky regions in Cubeviz.
@@ -59,14 +59,18 @@ class TestLoadRegions(BaseRegionHandler):
 
         # Manually draw wavelength range.
         unit = u.Unit(self.cubeviz.plugins['Unit Conversion'].spectral_unit.selected)
-        self.cubeviz.plugins['Subset Tools']._obj.import_region(SpectralRegion(4.892 * unit,
-                                                                               4.896 * unit))
+        self.cubeviz.plugins['Subset Tools'].import_region(SpectralRegion(4.892 * unit,
+                                                                          4.896 * unit))
         self.cubeviz.app.session.edit_subset_mode.edit_subset = None
 
-        # Get interactive spatial regions only.
-        spatial_subsets = self.cubeviz.get_interactive_regions()
-        assert list(spatial_subsets.keys()) == ['Subset 1'], spatial_subsets
-        assert isinstance(spatial_subsets['Subset 1'], EllipsePixelRegion)
+        # Get spatial regions only.
+        st = self.cubeviz.plugins['Subset Tools']._obj
+        spatial_subsets_as_regions = st.get_regions(region_type='spatial')
+        assert list(spatial_subsets_as_regions.keys()) == ['Subset 1'], spatial_subsets_as_regions
+        assert isinstance(spatial_subsets_as_regions['Subset 1'], EllipsePixelRegion)
+        # ensure agreement between app.get_subsets and subset_tools.get_regions
+        ss = self.cubeviz.app.get_subsets()
+        assert ss['Subset 1'][0]['region'] == spatial_subsets_as_regions['Subset 1']
 
         # NOTE: This does not test that spectrum from Subset is actually scientifically accurate.
         # Get spectral regions only.
