@@ -23,7 +23,7 @@ class MetadataViewer(PluginTemplateMixin, DatasetSelectMixin):
       Dataset to expose the metadata.
     * :attr:`show_primary`:
       Whether to show MEF primary header metadata instead.
-    * :attr:`metadata`:
+    * :attr:`meta`:
       Read-only metadata. If the data is loaded from a multi-extension FITS file,
       this can be the extension header or the primary header, depending on
       ``show_primary`` setting.
@@ -42,9 +42,13 @@ class MetadataViewer(PluginTemplateMixin, DatasetSelectMixin):
         # override the default filters on dataset entries to require metadata in entries
         self.dataset.add_filter('not_from_plugin')
 
+        # description displayed under plugin title in tray
+        self._plugin_description = 'View metadata.'
+
     @property
     def user_api(self):
-        return PluginUserApi(self, expose=('dataset', 'show_primary'), readonly=('metadata',))
+        return PluginUserApi(self, expose=('dataset', 'show_primary'),
+                             readonly=('metadata', 'meta'), deprecated=('metadata', ))
 
     def reset(self):
         self.has_metadata = False
@@ -97,8 +101,10 @@ class MetadataViewer(PluginTemplateMixin, DatasetSelectMixin):
 
         d = flatten_nested_dict(meta)
         # Some FITS keywords cause "# ipykernel cannot clean for JSON" messages.
-        # Also, we want to hide internal metadata that starts with underscore.
-        badkeys = ['COMMENT', 'HISTORY', ''] + [k for k in d if k.startswith('_')]
+        # Also, we want to hide internal metadata that starts with underscore
+        # and some "original_" entries from specutils.
+        badkeys = (['COMMENT', 'HISTORY', ''] + [k for k in d if k.startswith('_')]
+                   + [k for k in d if k.startswith('original_')])
         for badkey in badkeys:
             if badkey in d:
                 del d[badkey]
@@ -127,6 +133,11 @@ class MetadataViewer(PluginTemplateMixin, DatasetSelectMixin):
         else:
             self.reset()
 
+    @property
+    def meta(self):
+        return dict((key, {"value": val, "description": cmt})
+                    for key, val, cmt in self.metadata)
+
 
 # TODO: If this generalized in stdatamodels in the future, replace with native function.
 #       See https://github.com/spacetelescope/stdatamodels/issues/131
