@@ -7,6 +7,10 @@ from specutils import Spectrum1D
 from specutils.utils import QuantityModel
 from traitlets import Bool, List, Unicode, observe
 
+from jdaviz.configs.default.plugins.model_fitting.fitting_backend import fit_model_to_spectrum
+from jdaviz.configs.default.plugins.model_fitting.initializers import (MODELS,
+                                                                       initialize,
+                                                                       get_model_parameters)
 from jdaviz.core.events import SnackbarMessage, GlobalDisplayUnitChanged
 from jdaviz.core.registries import tray_registry
 from jdaviz.core.template_mixin import (PluginTemplateMixin,
@@ -21,11 +25,9 @@ from jdaviz.core.template_mixin import (PluginTemplateMixin,
                                         with_spinner)
 from jdaviz.core.custom_traitlets import IntHandleEmpty
 from jdaviz.core.user_api import PluginUserApi
-from jdaviz.configs.default.plugins.model_fitting.fitting_backend import fit_model_to_spectrum
-from jdaviz.configs.default.plugins.model_fitting.initializers import (MODELS,
-                                                                       initialize,
-                                                                       get_model_parameters)
-from jdaviz.utils import _eqv_flux_to_sb_pixel
+from jdaviz.core.unit_conversion_utils import (all_flux_unit_conversion_equivs,
+                                               flux_conversion_general)
+from jdaviz.core.custom_units_and_equivs import PIX2
 
 __all__ = ['ModelFitting']
 
@@ -120,6 +122,9 @@ class ModelFitting(PluginTemplateMixin, DatasetSelectMixin,
         self._initialized_models = {}
         self._display_order = False
 
+        # description displayed under plugin title in tray
+        self._plugin_description = 'Fit an analytic model to data or a subset of data.'
+
         # create the label first so that when model_component defaults to the first selection,
         # the label automatically defaults as well
         self.model_component_label = AutoTextField(self, 'comp_label', 'comp_label_default',
@@ -504,7 +509,17 @@ class ModelFitting(PluginTemplateMixin, DatasetSelectMixin,
                 # then the model parameter has default units.  We want to pass
                 # with jdaviz default units (based on x/y units) but need to
                 # convert the default parameter unit to these units
-                initial_val = default_param.quantity.to(default_units)
+                if default_param.unit != default_units:
+                    pixar_sr = self.app.data_collection[0].meta.get('PIXAR_SR', 1)
+                    viewer = self.app.get_viewer("spectrum-viewer")
+                    cube_wave = viewer.slice_value * u.Unit(self.app._get_display_unit('spectral'))
+                    equivs = all_flux_unit_conversion_equivs(pixar_sr, cube_wave)
+
+                    initial_val = flux_conversion_general([default_param.value],
+                                                          default_param.unit,
+                                                          default_units, equivs)
+                else:
+                    initial_val = default_param
 
             initial_values[param_name] = initial_val
 
@@ -535,10 +550,15 @@ class ModelFitting(PluginTemplateMixin, DatasetSelectMixin,
             init_x = masked_spectrum.spectral_axis
             init_y = masked_spectrum.flux
 
-        # equivs for spectral density and flux<>flux/pix2. revisit
-        # when generalizing plugin UC equivs.
-        equivs = _eqv_flux_to_sb_pixel() + u.spectral_density(init_x)
-        init_y = init_y.to(self._units['y'], equivs)
+        if init_y.unit != self._units['y']:
+            # equivs for spectral density and flux<>sb
+            pixar_sr = masked_spectrum.meta.get('_pixel_scale_factor', 1.0)
+            equivs = all_flux_unit_conversion_equivs(pixar_sr, init_x)
+
+            init_y = flux_conversion_general([init_y.value],
+                                             init_y.unit,
+                                             self._units['y'],
+                                             equivs)
 
         initialized_model = initialize(
             MODELS[model_comp](name=comp_label,
@@ -963,7 +983,23 @@ class ModelFitting(PluginTemplateMixin, DatasetSelectMixin,
 
         sb_unit = self.app._get_display_unit('sb')
         if spec.flux.unit != sb_unit:
-            spec = spec.with_flux_unit(sb_unit)
+            # ensure specutils has access to jdaviz custom unit equivalencies
+            pixar_sr = spec.meta.get('_pixel_scale_factor', None)
+            equivalencies = all_flux_unit_conversion_equivs(pixar_sr=pixar_sr,
+                                                            cube_wave=spec.spectral_axis)
+
+            pix2_in_flux = 'pix2' in spec.flux.unit.to_string()
+            pix2_in_sb = 'pix2' in sb_unit
+            # Handle various cases when PIX2 angle unit is present in the conversion
+            if pix2_in_flux and pix2_in_sb:
+                spec = spec.with_flux_unit(u.Unit(spec.flux.unit)*PIX2, equivalencies=equivalencies)  # noqa
+                spec = spec.with_flux_unit(u.Unit(sb_unit)*PIX2, equivalencies=equivalencies)
+            elif pix2_in_flux:
+                spec = spec.with_flux_unit(u.Unit(spec.flux.unit) * PIX2, equivalencies=equivalencies)  # noqa
+            elif pix2_in_sb:
+                spec = spec.with_flux_unit(u.Unit(spec.flux.unit) / PIX2, equivalencies=equivalencies)  # noqa
+
+            spec = spec.with_flux_unit(sb_unit, equivalencies=equivalencies)
 
         snackbar_message = SnackbarMessage(
             "Fitting model to cube...",
