@@ -194,8 +194,8 @@ def test_toggle_cube_fit_subset(cubeviz_helper):
     mf = cubeviz_helper.plugins['Model Fitting']
 
     unit = u.Unit(cubeviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
-    cubeviz_helper.plugins['Subset Tools']._obj.import_region(SpectralRegion(7.5 * unit,
-                                                                             8 * unit))
+    cubeviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(7.5 * unit,
+                                                                        8 * unit))
 
     mf.spectral_subset = 'Subset 1'
     mf.cube_fit = True
@@ -308,8 +308,8 @@ def test_reestimate_parameters(specviz_helper, spectrum1d):
     assert mc['parameters']['stddev']['fixed'] is True
 
     unit = u.Unit(specviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
-    specviz_helper.plugins['Subset Tools']._obj.import_region(SpectralRegion(7500 * unit,
-                                                                             8000 * unit))
+    specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(7500 * unit,
+                                                                        8000 * unit))
 
     mf.spectral_subset = 'Subset 1'
 
@@ -327,7 +327,7 @@ def test_subset_masks(cubeviz_helper, spectrum1d_cube_larger):
     assert spectrum1d_cube_larger.mask is None
 
     # create a "Subset 1" entry in spatial dimension, selected "interactively"
-    cubeviz_helper.plugins['Subset Tools']._obj.import_region(CircularROI(0.5, 0.5, 1))
+    cubeviz_helper.plugins['Subset Tools'].import_region(CircularROI(0.5, 0.5, 1))
 
     # check that when no subset is selected, the spectral cube has no mask:
     p = cubeviz_helper.app.get_tray_item_from_name('g-model-fitting')
@@ -342,7 +342,7 @@ def test_subset_masks(cubeviz_helper, spectrum1d_cube_larger):
     sv.toolbar_active_subset.selected = []
 
     # Now create the new spectral subset:
-    cubeviz_helper.plugins['Subset Tools']._obj.import_region(
+    cubeviz_helper.plugins['Subset Tools'].import_region(
         SpectralRegion(min_wavelength.to(u.m), max_wavelength.to(u.m)))
     assert "Subset 2" in p.spectral_subset.choices
 
@@ -376,8 +376,8 @@ def test_invalid_subset(specviz_helper, spectrum1d):
     # NOTE: using a subset that overlaps the right_spectrum (reference) results in errors when
     # retrieving the subset (https://github.com/spacetelescope/jdaviz/issues/1868)
     unit = u.Unit(specviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
-    specviz_helper.plugins['Subset Tools']._obj.import_region(SpectralRegion(5000 * unit,
-                                                                             6000 * unit))
+    specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(5000 * unit,
+                                                                        6000 * unit))
 
     plugin = specviz_helper.plugins['Model Fitting']
     plugin.create_model_component('Linear1D')
