@@ -10,7 +10,7 @@ from echo import delay_callback
 from traitlets import Any, Dict, Float, Bool, Int, List, Unicode, observe
 
 from glue.core.subset_group import GroupedSubset
-from glue.config import colormaps, stretches
+from glue.config import stretches as glue_stretches
 from glue.viewers.scatter.state import ScatterViewerState
 from glue.viewers.profile.state import ProfileViewerState, ProfileLayerState
 from glue.viewers.image.state import ImageSubsetLayerState, ImageViewerState
@@ -20,47 +20,24 @@ from glue_jupyter.bqplot.image.state import BqplotImageLayerState
 from glue_jupyter.common.toolbar_vuetify import read_icon
 
 from jdaviz.core.registries import tray_registry
-from jdaviz.core.template_mixin import (PluginTemplateMixin, ViewerSelect, LayerSelect,
+from jdaviz.core.template_mixin import (PluginTemplateMixin, ViewerSelectMixin, LayerSelect,
                                         PlotOptionsSyncState, Plot,
                                         skip_if_no_updates_since_last_active, with_spinner)
 from jdaviz.core.events import ChangeRefDataMessage
 from jdaviz.core.user_api import PluginUserApi
 from jdaviz.core.tools import ICON_DIR
 from jdaviz.core.custom_traitlets import IntHandleEmpty
-from jdaviz.utils import is_not_wcs_only
+# by importing from utils, glue_colormaps will include the custom Random colormap
+from jdaviz.utils import is_not_wcs_only, cmap_samples, glue_colormaps
 
 
 from scipy.interpolate import PchipInterpolator
-from photutils.utils import make_random_cmap
 
 __all__ = ['PlotOptions']
 
 RANDOM_SUBSET_SIZE = 10_000
 
 
-def _register_random_cmap(
-    cmap_name,
-    bkg_color=[0, 0, 0],
-    bkg_alpha=1,
-    seed=42,
-    ncolors=10_000
-):
-    """
-    Custom random colormap, useful for rendering image
-    segmentation maps. The default background for
-    `label==0` is *transparent*. If the segmentation map
-    contains more than 10,000 labels, adjust the `ncolors`
-    kwarg to ensure uniqueness.
-    """
-    cmap = make_random_cmap(ncolors=ncolors, seed=seed)
-    cmap.colors[0] = bkg_color + [bkg_alpha]
-    cmap.name = cmap_name
-    colormaps.add(cmap_name, cmap)
-
-
-_register_random_cmap('Random', bkg_alpha=1)
-
-
 class SplineStretch:
     """
     A class to represent spline stretches.
@@ -117,8 +94,8 @@ class SplineStretch:
 
 
 # Add the spline stretch to the glue stretch registry if not registered
-if "spline" not in stretches:
-    stretches.add("spline", SplineStretch, display="Spline")
+if "spline" not in glue_stretches:
+    glue_stretches.add("spline", SplineStretch, display="Spline")
 
 
 def _round_step(step):
@@ -132,7 +109,7 @@ def _round_step(step):
 
 
 @tray_registry('g-plot-options', label="Plot Options")
-class PlotOptions(PluginTemplateMixin):
+class PlotOptions(PluginTemplateMixin, ViewerSelectMixin):
     """
     The Plot Options Plugin gives access to per-viewer and per-layer options and enables
     setting across multiple viewers/layers simultaneously.
@@ -215,9 +192,6 @@ class PlotOptions(PluginTemplateMixin):
     # read-only display units
     display_units = Dict().tag(sync=True)
 
-    viewer_multiselect = Bool(False).tag(sync=True)
-    viewer_items = List().tag(sync=True)
-    viewer_selected = Any().tag(sync=True)  # Any needed for multiselect
     viewer_limits = Dict().tag(sync=True)
 
     layer_multiselect = Bool(False).tag(sync=True)
@@ -397,16 +371,17 @@ class PlotOptions(PluginTemplateMixin):
     icon_radialtocheck = Unicode(read_icon(os.path.join(ICON_DIR, 'radialtocheck.svg'), 'svg+xml')).tag(sync=True)  # noqa
     icon_checktoradial = Unicode(read_icon(os.path.join(ICON_DIR, 'checktoradial.svg'), 'svg+xml')).tag(sync=True)  # noqa
 
-    show_viewer_labels = Bool(True).tag(sync=True)
-
-    cmap_samples = Dict().tag(sync=True)
+    cmap_samples = Dict(cmap_samples).tag(sync=True)
     swatches_palette = List().tag(sync=True)
     apply_RGB_presets_spinner = Bool(False).tag(sync=True)
     stretch_hist_spinner = Bool(False).tag(sync=True)
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.viewer = ViewerSelect(self, 'viewer_items', 'viewer_selected', 'viewer_multiselect')
+
+        # description displayed under plugin title in tray
+        self._plugin_description = 'Set viewer and layer display options.'
+
         self.layer = LayerSelect(self, 'layer_items', 'layer_selected',
                                  'viewer_selected', 'layer_multiselect')
 
@@ -652,10 +627,6 @@ class PlotOptions(PluginTemplateMixin):
         self.axes_visible = PlotOptionsSyncState(self, self.viewer, self.layer, 'show_axes',
                                                  'axes_visible_value', 'axes_visible_sync',
                                                  state_filter=not_profile)
-
-        self.show_viewer_labels = self.app.state.settings['viewer_labels']
-        self.app.state.add_callback('settings', self._on_app_settings_changed)
-
         sv = self.spectrum_viewer
         if sv is not None:
             sv.state.add_callback('x_display_unit',
@@ -666,13 +637,6 @@ class PlotOptions(PluginTemplateMixin):
         self.hub.subscribe(self, ChangeRefDataMessage,
                            handler=self._on_refdata_change)
 
-        # give UI access to sampled version of the available colormap choices
-        def hex_for_cmap(cmap):
-            N = 50
-            cm_sampled = cmap.resampled(N)
-            return [matplotlib.colors.to_hex(cm_sampled(i)) for i in range(N)]
-        self.cmap_samples = {cmap[1].name: hex_for_cmap(cmap[1]) for cmap in colormaps.members}
-
     @property
     def user_api(self):
         expose = ['multiselect', 'viewer', 'viewer_multiselect', 'layer', 'layer_multiselect',
@@ -697,13 +661,6 @@ class PlotOptions(PluginTemplateMixin):
 
         return PluginUserApi(self, expose)
 
-    @observe('show_viewer_labels')
-    def _on_show_viewer_labels_changed(self, event):
-        self.app.state.settings['viewer_labels'] = event['new']
-
-    def _on_app_settings_changed(self, value):
-        self.show_viewer_labels = value['viewer_labels']
-
     @property
     def multiselect(self):
         logging.warning(f"DeprecationWarning: multiselect has been replaced by separate viewer_multiselect and layer_multiselect and will be removed in the future.  This currently evaluates viewer_multiselect or layer_multiselect")  # noqa
@@ -1085,7 +1042,7 @@ class PlotOptions(PluginTemplateMixin):
         data = stretch(data, out=data)
 
         if color_mode == 'Colormaps':
-            cmap = colormaps[self.image_colormap.text]
+            cmap = glue_colormaps[self.image_colormap.text]
             if hasattr(cmap, "get_bad"):
                 bad_color = cmap.get_bad().tolist()[:3]
                 layer_cmap = cmap.with_extremes(bad=bad_color + [self.image_opacity_value])
