@@ -137,6 +137,15 @@ def test_stretch_histogram(cubeviz_helper, spectrum1d_cube_with_uncerts):
     assert po.stretch_histogram.marks['vmin'].x[0] == po.stretch_vmin.value
     assert po.stretch_histogram.marks['vmax'].x[0] == po.stretch_vmax.value
 
+    # Make sure some tools work
+
+    po_panzoom = po.stretch_histogram.toolbar.tools["jdaviz:panzoom"]
+    po_panzoom.activate()
+    po_panzoom.deactivate()
+
+    po_prevzoom = po.stretch_histogram.toolbar.tools["jdaviz:prevzoom"]
+    po_prevzoom.activate()
+
 
 @pytest.mark.filterwarnings('ignore')
 def test_user_api(cubeviz_helper, spectrum1d_cube):
@@ -422,3 +431,30 @@ def test_segmentation_image(imviz_helper):
     assert plot_opts.stretch_function.value == 'linear'
     assert plot_opts.image_bias.value == 0.5
     assert plot_opts.image_contrast.value == 1.0
+
+
+def test_imviz_select_all_layers(imviz_helper):
+    """
+    Test to catch a (fixed) bug that was revealed when trying to select
+    all layers when data is float32. This was caused when trying to set
+    `stretch_vmin_value`.
+    """
+
+    arr = np.arange(36.).reshape(6, 6).astype(np.float32)
+
+    # load three images in one viewer
+    with imviz_helper.batch_load():
+        for i in range(3):
+            imviz_helper.load_data(arr, data_label=f"data_{i}")
+
+    plot_options = imviz_helper.plugins['Plot Options']
+
+    plot_options.layer.multiselect = True
+    plot_options.select_all()
+
+    # all layers selected, set stretch function to log for all
+    plot_options.stretch_function = 'log'
+
+    # and make sure each layer picked up this change
+    for layer in plot_options.image_colormap.linked_states:
+        assert layer.as_dict()['stretch'] == 'log'
