@@ -7,70 +7,24 @@ from glue.viewers.common.tool import CheckableTool
 from glue_jupyter.bqplot.image import BqplotImageView
 from glue_jupyter.utils import debounced
 
-from jdaviz.core.tools import BoxZoom, PanZoom
+from jdaviz.core.tools import BoxZoom, PanZoom, _MatchedZoomMixin
+from jdaviz.utils import get_top_layer_index
 
 __all__ = []
 
 ICON_DIR = os.path.join(os.path.dirname(__file__), '..', '..', '..', 'data', 'icons')
 
 
-class _MatchedZoomMixin:
-    def _iter_image_viewers(self):
-        for viewer in self.viewer.session.application.viewers:
-            if isinstance(viewer, BqplotImageView):
-                yield viewer
+class _ImvizMatchedZoomMixin(_MatchedZoomMixin):
+    match_axes = []
+    disable_matched_zoom_in_other_viewer = True
 
-    def save_prev_zoom(self):
-        # override the behavior in core.tools._BaseZoomHistory to store viewer limits
-        # for all referenced viewers.  This enables the previous zoom button to work for
-        # a viewer whose zoom was changed by a MatchedZoom instance from another viewer
-        for viewer in self._iter_image_viewers():
-            viewer._prev_limits = (viewer.state.x_min, viewer.state.x_max,
-                                   viewer.state.y_min, viewer.state.y_max)
+    @property
+    def match_keys(self):
+        return ['zoom_center_x', 'zoom_center_y', 'zoom_radius']
 
-    def activate(self):
-
-        super().activate()
-        self.viewer.state.add_callback('x_min', self.on_limits_change)
-        self.viewer.state.add_callback('x_max', self.on_limits_change)
-        self.viewer.state.add_callback('y_min', self.on_limits_change)
-        self.viewer.state.add_callback('y_max', self.on_limits_change)
-
-        # NOTE: For Imviz only.
-        # Set the reference data in other viewers to be the same as the current viewer.
-        # If adding the data to the viewer, make sure it is not actually shown since the
-        # user didn't request it.
-        if self.viewer.jdaviz_app.config == 'imviz':
-            for viewer in self._iter_image_viewers():
-                if viewer is not self.viewer:
-                    if self.viewer.state.reference_data not in viewer.state.layers_data:
-                        viewer.add_data(self.viewer.state.reference_data)
-                        for layer in viewer.state.layers:
-                            if layer.layer is self.viewer.state.reference_data:
-                                layer.visible = False
-                                break
-                    viewer.state.reference_data = self.viewer.state.reference_data
-
-        # Trigger a sync so the initial limits match
-        self.on_limits_change()
-
-    def deactivate(self):
-
-        self.viewer.state.remove_callback('x_min', self.on_limits_change)
-        self.viewer.state.remove_callback('x_max', self.on_limits_change)
-        self.viewer.state.remove_callback('y_min', self.on_limits_change)
-        self.viewer.state.remove_callback('y_max', self.on_limits_change)
-
-        super().deactivate()
-
-    def on_limits_change(self, *args):
-        for viewer in self._iter_image_viewers():
-            if viewer is not self.viewer:
-                with delay_callback(viewer.state, 'x_min', 'x_max', 'y_min', 'y_max'):
-                    viewer.state.x_min = self.viewer.state.x_min
-                    viewer.state.x_max = self.viewer.state.x_max
-                    viewer.state.y_min = self.viewer.state.y_min
-                    viewer.state.y_max = self.viewer.state.y_max
+    def _is_matched_viewer(self, viewer):
+        return isinstance(viewer, BqplotImageView)
 
 
 @viewer_tool
@@ -88,15 +42,18 @@ class ImagePanZoom(PanZoom):
 
     def on_click(self, data):
         # Find visible layers
-        visible_layers = [layer for layer in self.viewer.state.layers if layer.visible]
-        if len(visible_layers) == 0:
+        try:
+            i = get_top_layer_index(self.viewer)
+        except IndexError:
+            return
+        if i is None:
             return
 
         # Same data as mousemove event in Imviz viewer.
         # Any other config that wants this functionality has to have the following:
         #   viewer._get_real_xy()
         #   viewer.center_on() --> inherited from AstrowidgetsImageViewerMixin
-        image = visible_layers[0].layer
+        image = self.viewer.state.layers[i].layer
         x = data['domain']['x']
         y = data['domain']['y']
         if x is None or y is None:  # Out of bounds
@@ -122,9 +79,12 @@ class BlinkOnce(CheckableTool):
     def on_click(self, data):
         self.viewer.blink_once(reversed=data['event']=='contextmenu')  # noqa: E225
 
+    def is_visible(self):
+        return len(self.viewer.state.layers) > 1
+
 
 @viewer_tool
-class MatchBoxZoom(_MatchedZoomMixin, BoxZoom):
+class MatchBoxZoom(_ImvizMatchedZoomMixin, BoxZoom):
     icon = os.path.join(ICON_DIR, 'zoom_box_match.svg')
     tool_id = 'jdaviz:boxzoommatch'
     action_text = 'Box zoom, matching between viewers'
@@ -132,7 +92,7 @@ class MatchBoxZoom(_MatchedZoomMixin, BoxZoom):
 
 
 @viewer_tool
-class MatchPanZoom(_MatchedZoomMixin, ImagePanZoom):
+class MatchPanZoom(_ImvizMatchedZoomMixin, ImagePanZoom):
     icon = os.path.join(ICON_DIR, 'panzoom_match.svg')
     tool_id = 'jdaviz:panzoommatch'
     action_text = 'Pan, matching between viewers'
@@ -179,7 +139,7 @@ class ContrastBias(CheckableTool):
             self._layer_state.contrast = contrast
 
     def on_mouse_or_key_event(self, data):
-        from jdaviz.configs.imviz.helper import get_top_layer_index
+        from jdaviz.utils import get_top_layer_index
 
         event = data['event']
 
