@@ -9,14 +9,14 @@ from astropy.utils.data import download_file
 from astropy.wcs import WCS
 from gwcs import WCS as GWCS
 from numpy.testing import assert_allclose, assert_array_equal
-from regions import CirclePixelRegion, RectanglePixelRegion
+from regions import CirclePixelRegion, PixCoord, RectanglePixelRegion
 from skimage.io import imsave
 from stdatamodels import asdf_in_fits
 
 from jdaviz.configs.imviz.helper import split_filename_with_fits_ext
 from jdaviz.configs.imviz.plugins.parsers import (
     parse_data, _validate_fits_image2d, _validate_bunit, _parse_image, HAS_ROMAN_DATAMODELS)
-from jdaviz.core.custom_units import PIX2
+from jdaviz.core.custom_units_and_equivs import PIX2
 
 
 @pytest.mark.parametrize(
@@ -259,10 +259,17 @@ class TestParseImage:
         imviz_helper._apply_interactive_region('bqplot:rectangle',
                                                (982, 1088),
                                                (1008, 1077))  # Background
-        subsets = imviz_helper.get_interactive_regions()
+        subsets = imviz_helper.plugins['Subset Tools'].get_regions()
         assert list(subsets.keys()) == ['Subset 1', 'Subset 2'], subsets
+        # check that retrieved subsets-as-regions from subset plugin match what was loaded.
         assert isinstance(subsets['Subset 1'], CirclePixelRegion)
+        assert subsets['Subset 1'].center == PixCoord(970.95, 1116.05)
         assert isinstance(subsets['Subset 2'], RectanglePixelRegion)
+        assert subsets['Subset 2'].center == PixCoord(995.0, 1082.5)
+        # ensure agreement between app.get_subsets and subset_tools.get_regions
+        ss = imviz_helper.app.get_subsets()
+        assert ss['Subset 1'][0]['region'] == subsets['Subset 1']
+        assert ss['Subset 2'][0]['region'] == subsets['Subset 2']
 
         # Test simple aperture photometry plugin.
         phot_plugin = imviz_helper.app.get_tray_item_from_name('imviz-aper-phot-simple')
@@ -413,7 +420,7 @@ class TestParseImage:
         assert_allclose(sky.dec.deg, 10.802045612042956, rtol=1e-3)
         data_unit = u.electron / u.s
         assert_quantity_allclose(tbl[0]['background'], 0.0014 * data_unit)
-        assert_quantity_allclose(tbl[0]['sum'], 115.944737 * data_unit, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['sum'], 112.712406 * data_unit, rtol=1e-3)
         assert_quantity_allclose(tbl[0]['sum_aper_area'], 2583.959958 * PIX2, rtol=1e-3)
         assert_array_equal(tbl[0]['pixarea_tot'], None)
         assert_array_equal(tbl[0]['aperture_sum_counts'], None)
@@ -421,21 +428,21 @@ class TestParseImage:
         assert_array_equal(tbl[0]['counts_fac'], None)
         assert_array_equal(tbl[0]['aperture_sum_mag'], None)
         assert_array_equal(tbl[0]['flux_scaling'], None)
-        assert_quantity_allclose(tbl[0]['min'], -0.042749 * data_unit, rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['max'], 1.588676 * data_unit, rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['mean'], 0.04495 * data_unit, rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['median'], 0.021585 * data_unit, rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['mode'], -0.025143 * data_unit, rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['std'], 0.102367 * data_unit, rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['mad_std'], 0.023415 * data_unit, rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['var'], 0.010479 * (data_unit * data_unit), rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['biweight_location'], 0.021173 * data_unit, rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['biweight_midvariance'], 0.00062 * (data_unit * data_unit), rtol=1e-3)  # noqa
-        assert_quantity_allclose(tbl[0]['fwhm'], 21.538407 * u.pix, rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['semimajor_sigma'], 10.04406 * u.pix, rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['semiminor_sigma'], 8.150735 * u.pix, rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['orientation'], 79.605418 * u.deg, rtol=1e-3)
-        assert_quantity_allclose(tbl[0]['eccentricity'], 0.584355, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['min'], -0.02422 * data_unit, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['max'], 1.577081 * data_unit, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['mean'], 0.043684 * data_unit, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['median'], 0.02129 * data_unit, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['mode'], -0.023497 * data_unit, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['std'], 0.09908 * data_unit, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['mad_std'], 0.023219 * data_unit, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['var'], 0.009817 * (data_unit * data_unit), rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['biweight_location'], 0.020978 * data_unit, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['biweight_midvariance'], 0.000606 * (data_unit * data_unit), rtol=1e-3)  # noqa
+        assert_quantity_allclose(tbl[0]['fwhm'], 21.230628 * u.pix, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['semimajor_sigma'], 9.712415 * u.pix, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['semiminor_sigma'], 8.260686 * u.pix, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['orientation'], 80.054019 * u.deg, rtol=1e-3)
+        assert_quantity_allclose(tbl[0]['eccentricity'], 0.525929, rtol=1e-3)
 
         # Request specific extension (name only), use given label
         imviz_helper.load_data(filename, ext='CTX', data_label='jclj01010_drz',
