@@ -16,7 +16,7 @@ from regions import (CircleAnnulusPixelRegion, CirclePixelRegion, EllipsePixelRe
 from jdaviz.configs.imviz.plugins.aper_phot_simple.aper_phot_simple import (
     _curve_of_growth, _radial_profile)
 from jdaviz.configs.imviz.tests.utils import BaseImviz_WCS_WCS, BaseImviz_WCS_NoWCS
-from jdaviz.core.custom_units import PIX2
+from jdaviz.core.custom_units_and_equivs import PIX2
 from jdaviz.tests.test_utils import PHOTUTILS_LT_1_12_1
 
 
@@ -25,7 +25,7 @@ class TestSimpleAperPhot(BaseImviz_WCS_WCS):
         self.imviz.link_data(align_by='wcs')  # They are dithered by 1 pixel on X
 
         reg = CirclePixelRegion(center=PixCoord(x=4.5, y=4.5), radius=4.5).to_sky(self.wcs_1)
-        self.imviz.plugins['Subset Tools']._obj.import_region(reg)
+        self.imviz.plugins['Subset Tools'].import_region(reg)
 
         phot_plugin = self.imviz.app.get_tray_item_from_name('imviz-aper-phot-simple')
 
@@ -120,8 +120,8 @@ class TestSimpleAperPhot(BaseImviz_WCS_WCS):
 
         # Make sure it also works on an ellipse subset.
         reg = EllipsePixelRegion(center=PixCoord(x=4.5, y=2.0), width=9.0, height=4.0).to_sky(self.wcs_1)  # noqa: E501
-        self.imviz.plugins['Subset Tools']._obj.combination_mode.selected = 'new'
-        self.imviz.plugins['Subset Tools']._obj.import_region(reg)
+        self.imviz.plugins['Subset Tools'].combination_mode = 'new'
+        self.imviz.plugins['Subset Tools'].import_region(reg)
 
         phot_plugin.dataset_selected = 'has_wcs_1[SCI,1]'
         phot_plugin.aperture_selected = 'Subset 2'
@@ -144,8 +144,8 @@ class TestSimpleAperPhot(BaseImviz_WCS_WCS):
         # Make sure it also works on a rectangle subset.
         # We also subtract off background from itself here.
         reg = RectanglePixelRegion(center=PixCoord(x=4.5, y=4.5), width=9, height=9).to_sky(self.wcs_1)  # noqa: E501
-        self.imviz.plugins['Subset Tools']._obj.combination_mode.selected = 'new'
-        self.imviz.plugins['Subset Tools']._obj.import_region(reg)
+        self.imviz.plugins['Subset Tools'].combination_mode = 'new'
+        self.imviz.plugins['Subset Tools'].import_region(reg)
 
         phot_plugin.dataset_selected = 'has_wcs_1[SCI,1]'
         phot_plugin.aperture_selected = 'Subset 3'
@@ -282,7 +282,7 @@ class TestAdvancedAperPhot:
         w = imviz_helper.app.data_collection[0].coords
 
         # Regions to be used for aperture photometry
-        imviz_helper.plugins['Subset Tools']._obj.import_region([
+        imviz_helper.plugins['Subset Tools'].import_region([
             CirclePixelRegion(center=PixCoord(x=145.1, y=168.3), radius=5).to_sky(w),
             CirclePixelRegion(center=PixCoord(x=48.3, y=200.3), radius=5).to_sky(w),
             EllipsePixelRegion(center=PixCoord(x=84.7, y=224.1), width=23, height=9, angle=2.356 * u.rad).to_sky(w),  # noqa: E501
@@ -361,8 +361,8 @@ def test_annulus_background(imviz_helper):
     # Load annulus (this used to be part of the plugin but no longer)
     annulus_1 = CircleAnnulusPixelRegion(
         PixCoord(x=150, y=25), inner_radius=7, outer_radius=17)
-    imviz_helper.plugins['Subset Tools']._obj.import_region([circle_1, annulus_1],
-                                                            combination_mode='new')
+    imviz_helper.plugins['Subset Tools'].import_region([circle_1, annulus_1],
+                                                       combination_mode='new')
 
     phot_plugin.aperture_selected = 'Subset 1'
     phot_plugin.background_selected = 'Subset 2'
@@ -379,8 +379,8 @@ def test_annulus_background(imviz_helper):
     # Load annulus (this used to be part of the plugin but no longer)
     annulus_2 = CircleAnnulusPixelRegion(
         PixCoord(x=20.5, y=37.5), inner_radius=20.5, outer_radius=30.5)
-    imviz_helper.plugins['Subset Tools']._obj.import_region([ellipse_1, annulus_2],
-                                                            combination_mode='new')
+    imviz_helper.plugins['Subset Tools'].import_region([ellipse_1, annulus_2],
+                                                       combination_mode='new')
 
     # Subset 4 (annulus) should be available in both sets of choices, but invalid for selection as
     # aperture
@@ -412,7 +412,7 @@ def test_annulus_background(imviz_helper):
     assert_allclose(phot_plugin.background_value, bg_4gauss_2)
 
     # Edit the annulus and make sure background updates
-    subset_plugin = imviz_helper.plugins["Subset Tools"]._obj
+    subset_plugin = imviz_helper.plugins['Subset Tools']._obj
     subset_plugin.subset_selected = "Subset 4"
     subset_plugin._set_value_in_subset_definition(0, "X Center (pixels)", "value", 25.5)
     subset_plugin._set_value_in_subset_definition(0, "Y Center (pixels)", "value", 42.5)
@@ -431,7 +431,7 @@ def test_fit_radial_profile_with_nan(imviz_helper):
 
     # Mark an object of interest
     circle_1 = CirclePixelRegion(center=PixCoord(x=150, y=25), radius=7)
-    imviz_helper.plugins['Subset Tools']._obj.import_region(
+    imviz_helper.plugins['Subset Tools'].import_region(
         [circle_1], combination_mode='new')
 
     phot_plugin = imviz_helper.app.get_tray_item_from_name('imviz-aper-phot-simple')
@@ -528,7 +528,7 @@ def test_cubeviz_batch(cubeviz_helper, spectrum1d_cube_fluxunit_jy_per_steradian
     cubeviz_helper.load_data(spectrum1d_cube_fluxunit_jy_per_steradian, data_label='test')
     phot_plugin = cubeviz_helper.plugins['Aperture Photometry']._obj
     uc_plugin = cubeviz_helper.plugins['Unit Conversion']
-    subset_plugin = cubeviz_helper.plugins['Subset Tools']._obj
+    subset_plugin = cubeviz_helper.plugins['Subset Tools']
 
     subset_plugin.import_region(CirclePixelRegion(center=PixCoord(x=5, y=5), radius=2),
                                 combination_mode='new')
