@@ -1,6 +1,5 @@
 from collections.abc import Iterable
 import csv
-import glob
 import os
 from pathlib import Path
 import warnings
@@ -10,14 +9,14 @@ from astropy.io import fits
 from astropy.io.registry import IORegistryError
 from astropy.wcs import WCS
 from glue.core.data import Data
-from glue.core.link_helpers import LinkSame
+from glue.core.link_helpers import LinkSameWithUnits
 from specutils import Spectrum1D, SpectrumList, SpectrumCollection
 from specutils.io.default_loaders.jwst_reader import identify_jwst_s2d_multi_fits
 
 from jdaviz.configs.imviz.plugins.parsers import get_image_data_iterator
 from jdaviz.core.registries import data_parser_registry
 from jdaviz.core.events import SnackbarMessage
-from jdaviz.utils import standardize_metadata, PRIHDR_KEY
+from jdaviz.utils import standardize_metadata, PRIHDR_KEY, download_uri_to_path
 
 __all__ = ['mos_spec1d_parser', 'mos_spec2d_parser', 'mos_image_parser']
 
@@ -141,7 +140,7 @@ def link_data_in_table(app, data_obj=None):
             wc_spec_1d = app.session.data_collection[spec_1d].world_component_ids
             wc_spec_2d = app.session.data_collection[spec_2d].world_component_ids
 
-            wc_spec_ids.append(LinkSame(wc_spec_1d[0], wc_spec_2d[1]))
+            wc_spec_ids.append(LinkSameWithUnits(wc_spec_1d[0], wc_spec_2d[1]))
 
     app.session.data_collection.add_link(wc_spec_ids)
 
@@ -154,38 +153,46 @@ def mos_nirspec_directory_parser(app, data_obj, data_labels=None):
 
     # Load spectra
     level3_path = Path(data_obj)
-    for file_path in glob.iglob(str(level3_path / '*')):
+    for p in sorted(level3_path.glob('*.fits*')):
+        file_path = str(p)
         if 'x1d' in file_path or 'c1d' in file_path:
             spectra_1d.append(file_path)
         elif 's2d' in file_path:
             spectra_2d.append(file_path)
 
-    spectra_1d.sort()
-    spectra_2d.sort()
-    mos_spec1d_parser(app, spectra_1d)
+    n_specs = mos_spec1d_parser(app, spectra_1d)
     mos_spec2d_parser(app, spectra_2d)
 
     # Load images, if present
     image_path = None
 
     # Potential names of subdirectories where images are stored
-    for image_dir_name in ["cutouts", "mosviz_cutouts", "images"]:
-        if os.path.isdir(Path(str(level3_path / image_dir_name))):
-            image_path = Path(str(level3_path / image_dir_name))
+    for image_dir_name in ("cutouts", "mosviz_cutouts", "images"):
+        cur_path = level3_path / image_dir_name
+        if cur_path.is_dir():
+            image_path = cur_path
             break
     if image_path is not None:
-        images = sorted([file_path for file_path in glob.iglob(str(image_path / '*'))])
+        images = sorted(image_path.glob('*.fits*'))
+        n_images = len(images)
 
         # The amount of images needs to be equal to the amount of rows
         # of the other columns in the table
-        if len(images) == len(spectra_1d):
-            mos_image_parser(app, images)
+        if n_images == 1:
+            app._jdaviz_helper._shared_image = True
+            app.get_viewer(app._jdaviz_helper._default_table_viewer_reference_name)._shared_image = True  # noqa: E501
+            if n_specs > 1:
+                kwargs = {'share_image': n_specs}
+            else:
+                kwargs = {}
+            mos_image_parser(app, str(images[0]), **kwargs)
+        elif n_images == n_specs:
+            mos_image_parser(app, list(map(str, images)))
         else:
-            msg = ("The number of images in this directory does not match the"
-                   " number of spectra 1d and 2d files, please make the "
-                   "amounts equal or load images separately.")
-            msg = SnackbarMessage(msg, color='warning', sender=app)
-            app.hub.broadcast(msg)
+            app.hub.broadcast(SnackbarMessage(
+                "The number of images in this directory does not match the "
+                "number of spectra 1d and 2d files, please make the "
+                "amounts equal or load images separately.", color='warning', sender=app))
 
     mos_meta_parser(app)
 
@@ -205,8 +212,13 @@ def mos_spec1d_parser(app, data_obj, data_labels=None,
         the mosviz table.
     data_labels : str, optional
         The label applied to the glue data component.
-    """
 
+    Returns
+    -------
+    n_specs : int
+        Number of data objects loaded.
+
+    """
     if isinstance(data_labels, str):
         data_labels = [data_labels]
 
@@ -247,7 +259,8 @@ def mos_spec1d_parser(app, data_obj, data_labels=None,
 
 @data_parser_registry("mosviz-spec2d-parser")
 def mos_spec2d_parser(app, data_obj, data_labels=None, add_to_table=True,
-                      show_in_viewer=False, ext=1, transpose=False):
+                      show_in_viewer=False, ext=1, transpose=False,
+                      cache=None, local_path=None, timeout=None):
     """
     Attempts to parse a 2D spectrum object.
 
@@ -269,6 +282,23 @@ def mos_spec2d_parser(app, data_obj, data_labels=None, add_to_table=True,
         The extension in the FITS file that contains the data to be loaded.
     transpose : bool, optional
         Flag to transpose the data array before loading.
+    cache : None, bool, or str
+        Cache the downloaded file if the data are retrieved by a query
+        to a URL or URI.
+    local_path : str, optional
+        Cache remote files to this path. This is only used if data is
+        requested from `astroquery.mast`.
+    timeout : float, optional
+        If downloading from a remote URI, set the timeout limit for
+        remote requests in seconds (passed to
+        `~astropy.utils.data.download_file` or
+        `~astroquery.mast.Conf.timeout`).
+
+    Returns
+    -------
+    n_specs : int
+        Number of data objects loaded.
+
     """
     spectrum_2d_viewer_reference_name = (
         app._jdaviz_helper._default_spectrum_2d_viewer_reference_name
@@ -308,7 +338,7 @@ def mos_spec2d_parser(app, data_obj, data_labels=None, add_to_table=True,
         data_obj = [data_obj]
 
     # See if this is a multi s2d file
-    if len(data_obj) == 1 and _check_is_file(data_obj[0]):
+    if app.config == "mosviz" and len(data_obj) == 1 and _check_is_file(data_obj[0]):
         if identify_jwst_s2d_multi_fits("test", data_obj[0]):
             data_obj = SpectrumList.read(data_obj[0])
 
@@ -329,6 +359,10 @@ def mos_spec2d_parser(app, data_obj, data_labels=None, add_to_table=True,
             # If we got a filepath, first try and parse using the Spectrum1D and
             # SpectrumList parsers, and then fall back to parsing it as a generic
             # FITS file.
+
+            # try parsing file_obj as a URI/URL:
+            data = download_uri_to_path(data, cache=cache, local_path=local_path, timeout=timeout)
+
             if _check_is_file(data):
                 try:
                     if ext != 1 or transpose:
@@ -476,8 +510,10 @@ def mos_meta_parser(app, data_obj=None, ids=None):
     with app.data_collection.delay_link_manager_update():
 
         current_columns = [comp.label for comp in app.data_collection['MOS Table'].main_components]
+        has_1d = "1D Spectra" in current_columns
+
         # source name can be taken from 1d spectra
-        if "1D Spectra" in current_columns:
+        if has_1d:
             names = _get_source_identifiers(app, "1D Spectra", data_obj, ids)
             _add_to_table(app, names, "Identifier")
 
@@ -490,8 +526,20 @@ def mos_meta_parser(app, data_obj=None, ids=None):
 
             _add_to_table(app, filters_gratings, "Filter/Grating")
 
-        # source name and coordinates are taken from image headers, if present
-        if "Images" in current_columns:
+        # Grab target sky coordinates from 1D spectrum, if possible.
+        # This has to happen after Filter/Grating because columns are insertion-ordered.
+        if has_1d:
+            ra = query_metadata_by_component(app, "SRCRA", "1D Spectra", False)
+            dec = query_metadata_by_component(app, "SRCDEC", "1D Spectra", False)
+            if all(ra) and all(dec):
+                _add_to_table(app, ra, "R.A.")
+                _add_to_table(app, dec, "Dec.")
+
+        # Refresh current_columns for Images check
+        current_columns = [comp.label for comp in app.data_collection['MOS Table'].main_components]
+
+        # If not in 1D spectrum, source coordinates are taken from image headers, if present.
+        if "R.A." not in current_columns and "Images" in current_columns:
             ra = query_metadata_by_component(app, "OBJ_RA", "Images", FALLBACK_NAME)
             dec = query_metadata_by_component(app, "OBJ_DEC", "Images", FALLBACK_NAME)
             _add_to_table(app, ra, "R.A.")
@@ -666,7 +714,7 @@ def _id_files_by_datamodl(label_dict, filepaths, catalog_key=None):
         if fp.is_dir():
             # Potential names of subdirectories where images are stored
             if fp.name in ("cutouts", "mosviz_cutouts", "images"):
-                images = sorted([file_path for file_path in glob.iglob(str(fp / '*'))])
+                images = sorted(fp.glob('*.fits*'))
                 label_dict['Direct Image'] = images
             else:
                 continue
