@@ -1,6 +1,7 @@
 import warnings
 
 from astropy import units as u
+from astropy.utils.decorators import deprecated
 from regions.core.core import Region
 from glue.core.subset_group import GroupedSubset
 from specutils import SpectralRegion, Spectrum1D
@@ -41,7 +42,8 @@ class Specviz(ConfigHelper, LineListMixin):
                                handler=self._redshift_listener)
 
     def load_data(self, data, data_label=None, format=None, show_in_viewer=True,
-                  concat_by_file=False, cache=None, local_path=None, timeout=None):
+                  concat_by_file=False, cache=None, local_path=None, timeout=None,
+                  load_as_list=False):
         """
         Load data into Specviz.
 
@@ -80,7 +82,8 @@ class Specviz(ConfigHelper, LineListMixin):
                           concat_by_file=concat_by_file,
                           cache=cache,
                           local_path=local_path,
-                          timeout=timeout)
+                          timeout=timeout,
+                          load_as_list=load_as_list)
 
     def get_spectra(self, data_label=None, spectral_subset=None, apply_slider_redshift="Warn"):
         """Returns the current data loaded into the main viewer
@@ -145,6 +148,7 @@ class Specviz(ConfigHelper, LineListMixin):
 
             return output_spectra
 
+    @deprecated(since="4.1", alternative="subset_tools.get_regions")
     def get_spectral_regions(self, use_display_units=False):
         """
         A simple wrapper around the app-level call to retrieve only spectral
