@@ -8,7 +8,7 @@ from regions import RectanglePixelRegion, PixCoord
 from specutils import Spectrum1D, SpectralRegion
 
 from jdaviz.configs.specviz.plugins.line_analysis.line_analysis import _coerce_unit
-from jdaviz.core.custom_units import PIX2
+from jdaviz.core.custom_units_and_equivs import PIX2
 from jdaviz.core.events import LineIdentifyMessage
 from jdaviz.core.marks import LineAnalysisContinuum
 
@@ -32,8 +32,8 @@ def test_plugin(specviz_helper, spectrum1d):
 
     # add a region and rerun stats for that region
     unit = u.Unit(specviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
-    specviz_helper.plugins['Subset Tools']._obj.import_region(SpectralRegion(6500 * unit,
-                                                                             7400 * unit))
+    specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(6500 * unit,
+                                                                        7400 * unit))
     specviz_helper.app.state.drawer = True
 
     assert 'Subset 1' in plugin.spectral_subset.labels
@@ -58,14 +58,14 @@ def test_spatial_subset(cubeviz_helper, image_cube_hdu_obj):
     cubeviz_helper.load_data(image_cube_hdu_obj, data_label="Test Cube")
 
     # add a spatial region
-    cubeviz_helper.plugins['Subset Tools']._obj.import_region(
+    cubeviz_helper.plugins['Subset Tools'].import_region(
         RectanglePixelRegion(center=PixCoord(x=3, y=5), width=4, height=6))
 
     # create a spectral region
     unit = u.Unit(cubeviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
-    cubeviz_helper.plugins['Subset Tools']._obj.combination_mode.selected = 'new'
-    cubeviz_helper.plugins['Subset Tools']._obj.import_region(SpectralRegion(3.623e-7 * unit,
-                                                                             3.627e-7 * unit))
+    cubeviz_helper.plugins['Subset Tools'].combination_mode = 'new'
+    cubeviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(3.623e-7 * unit,
+                                                                        3.627e-7 * unit))
     cubeviz_helper.app.state.drawer = True
 
     plugin = cubeviz_helper.app.get_tray_item_from_name('specviz-line-analysis')
@@ -130,8 +130,8 @@ def test_user_api(specviz_helper, spectrum1d):
     specviz_helper.load_data(spectrum1d, data_label=label)
 
     unit = u.Unit(specviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
-    specviz_helper.plugins['Subset Tools']._obj.import_region(SpectralRegion(6500 * unit,
-                                                                             7400 * unit))
+    specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(6500 * unit,
+                                                                        7400 * unit))
 
     la = specviz_helper.plugins['Line Analysis']
     la.keep_active = True
@@ -247,8 +247,8 @@ def test_continuum_surrounding_spectral_subset(specviz_helper, spectrum1d):
 
     # add a region and rerun stats for that region
     unit = u.Unit(specviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
-    specviz_helper.plugins['Subset Tools']._obj.import_region(SpectralRegion(6500 * unit,
-                                                                             7400 * unit))
+    specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(6500 * unit,
+                                                                        7400 * unit))
     specviz_helper.app.state.drawer = True
 
     plugin = specviz_helper.app.get_tray_item_from_name('specviz-line-analysis')
@@ -276,8 +276,8 @@ def test_continuum_spectral_same_value(specviz_helper, spectrum1d):
 
     # add a region and rerun stats for that region
     unit = u.Unit(specviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
-    specviz_helper.plugins['Subset Tools']._obj.import_region(SpectralRegion(6500 * unit,
-                                                                             7400 * unit))
+    specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(6500 * unit,
+                                                                        7400 * unit))
     specviz_helper.app.state.drawer = True
 
     plugin = specviz_helper.app.get_tray_item_from_name('specviz-line-analysis')
@@ -305,8 +305,8 @@ def test_continuum_surrounding_invalid_width(specviz_helper, spectrum1d):
 
     # add a region and rerun stats for that region
     unit = u.Unit(specviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
-    specviz_helper.plugins['Subset Tools']._obj.import_region(SpectralRegion(6500 * unit,
-                                                                             7400 * unit))
+    specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(6500 * unit,
+                                                                        7400 * unit))
     specviz_helper.app.state.drawer = True
 
     plugin = specviz_helper.app.get_tray_item_from_name('specviz-line-analysis')
@@ -332,8 +332,8 @@ def test_continuum_subset_spectral_entire(specviz_helper, spectrum1d):
 
     # add a region and rerun stats for that region
     unit = u.Unit(specviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
-    specviz_helper.plugins['Subset Tools']._obj.import_region(SpectralRegion(6500 * unit,
-                                                                             7400 * unit))
+    specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(6500 * unit,
+                                                                        7400 * unit))
     specviz_helper.app.state.drawer = True
 
     plugin = specviz_helper.app.get_tray_item_from_name('specviz-line-analysis')
@@ -361,13 +361,13 @@ def test_continuum_subset_spectral_subset2(specviz_helper, spectrum1d):
 
     # add a region and rerun stats for that region
     unit = u.Unit(specviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
-    specviz_helper.plugins['Subset Tools']._obj.import_region(SpectralRegion(6200 * unit,
-                                                                             7000 * unit))
+    specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(6200 * unit,
+                                                                        7000 * unit))
     specviz_helper.app.state.drawer = True
 
-    specviz_helper.plugins['Subset Tools']._obj.combination_mode.selected = 'new'
-    specviz_helper.plugins['Subset Tools']._obj.import_region(SpectralRegion(7100 * unit,
-                                                                             7700 * unit))
+    specviz_helper.plugins['Subset Tools'].combination_mode = 'new'
+    specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(7100 * unit,
+                                                                        7700 * unit))
     specviz_helper.app.state.drawer = True
 
     plugin = specviz_helper.app.get_tray_item_from_name('specviz-line-analysis')
@@ -396,8 +396,8 @@ def test_continuum_surrounding_no_right(specviz_helper, spectrum1d):
 
     # add a region and rerun stats for that region
     unit = u.Unit(specviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
-    specviz_helper.plugins['Subset Tools']._obj.import_region(SpectralRegion(6500 * unit,
-                                                                             8000 * unit))
+    specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(6500 * unit,
+                                                                        8000 * unit))
     specviz_helper.app.state.drawer = True
 
     plugin = specviz_helper.app.get_tray_item_from_name('specviz-line-analysis')
@@ -426,8 +426,8 @@ def test_continuum_surrounding_no_left(specviz_helper, spectrum1d):
 
     # add a region and rerun stats for that region
     unit = u.Unit(specviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
-    specviz_helper.plugins['Subset Tools']._obj.import_region(SpectralRegion(6000 * unit,
-                                                                             7500 * unit))
+    specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(6000 * unit,
+                                                                        7500 * unit))
     specviz_helper.app.state.drawer = True
 
     plugin = specviz_helper.app.get_tray_item_from_name('specviz-line-analysis')
@@ -456,8 +456,8 @@ def test_subset_changed(specviz_helper, spectrum1d):
 
     # add a region and rerun stats for that region
     unit = u.Unit(specviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
-    specviz_helper.plugins['Subset Tools']._obj.import_region(SpectralRegion(6000 * unit,
-                                                                             7500 * unit))
+    specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(6000 * unit,
+                                                                        7500 * unit))
     specviz_helper.app.state.drawer = True
 
     plugin = specviz_helper.app.get_tray_item_from_name('specviz-line-analysis')
@@ -467,8 +467,8 @@ def test_subset_changed(specviz_helper, spectrum1d):
     plugin.continuum_subset_selected = 'Surrounding'
     plugin.width = 3
 
-    specviz_helper.plugins['Subset Tools']._obj.import_region(SpectralRegion(6500 * unit,
-                                                                             7500 * unit))
+    specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(6500 * unit,
+                                                                        7500 * unit))
     specviz_helper.app.state.drawer = True
 
     # Values have not yet been validated
@@ -488,8 +488,8 @@ def test_invalid_subset(specviz_helper, spectrum1d):
     # NOTE: using a subset that overlaps the right_spectrum (reference) results in errors when
     # retrieving the subset (https://github.com/spacetelescope/jdaviz/issues/1868)
     unit = u.Unit(specviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
-    specviz_helper.plugins['Subset Tools']._obj.import_region(SpectralRegion(5000 * unit,
-                                                                             6000 * unit))
+    specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(5000 * unit,
+                                                                        6000 * unit))
 
     plugin = specviz_helper.plugins['Line Analysis']
     plugin.dataset = 'right_spectrum'
