@@ -117,14 +117,16 @@ class TestSpecvizHelper:
                                  self.spec.flux, atol=1e-5*u.Unit(self.spec.flux.unit))
 
     def test_get_spectral_regions_none(self):
-        spec_region = self.spec_app.get_spectral_regions()
+        plg = self.spec_app.plugins['Subset Tools']
+        spec_region = plg.get_regions()
 
         assert spec_region == {}
 
     def test_get_spectral_regions_one(self):
-        self.spec_app.plugins['Subset Tools']._obj.import_region(
+        self.spec_app.plugins['Subset Tools'].import_region(
             SpectralRegion(6000*self.spec.spectral_axis.unit, 6500*self.spec.spectral_axis.unit))
-        spec_region = self.spec_app.get_spectral_regions()
+        plg = self.spec_app.plugins['Subset Tools']
+        spec_region = plg.get_regions()
         assert len(spec_region['Subset 1'].subregions) == 1
 
     def test_get_spectral_regions_two(self):
@@ -132,9 +134,9 @@ class TestSpecvizHelper:
                                  6500*self.spec.spectral_axis.unit) +
                   SpectralRegion(7300*self.spec.spectral_axis.unit,
                                  7800*self.spec.spectral_axis.unit))
-        self.spec_app.plugins['Subset Tools']._obj.import_region(subset, combination_mode='or')
+        self.spec_app.plugins['Subset Tools'].import_region(subset, combination_mode='or')
 
-        spec_region = self.spec_app.get_spectral_regions()
+        spec_region = self.spec_app.plugins['Subset Tools'].get_regions()
 
         assert len(spec_region['Subset 1'].subregions) == 2
 
@@ -145,9 +147,9 @@ class TestSpecvizHelper:
                                  7000*self.spec.spectral_axis.unit) +
                   SpectralRegion(7300*self.spec.spectral_axis.unit,
                                  7800*self.spec.spectral_axis.unit))
-        self.spec_app.plugins['Subset Tools']._obj.import_region(subset, combination_mode='or')
+        self.spec_app.plugins['Subset Tools'].import_region(subset, combination_mode='or')
 
-        spec_region = self.spec_app.get_spectral_regions()
+        spec_region = self.spec_app.plugins['Subset Tools'].get_regions()
 
         assert len(spec_region['Subset 1'].subregions) == 3
         # Assert correct values for test with 3 subregions
@@ -171,9 +173,9 @@ class TestSpecvizHelper:
                                  3*self.spec.spectral_axis.unit) +
                   SpectralRegion(4*self.spec.spectral_axis.unit,
                                  6*self.spec.spectral_axis.unit))
-        self.spec_app.plugins['Subset Tools']._obj.import_region(subset, combination_mode='or')
+        self.spec_app.plugins['Subset Tools'].import_region(subset, combination_mode='or')
 
-        spec_region = self.spec_app.get_spectral_regions()
+        spec_region = self.spec_app.plugins['Subset Tools'].get_regions()
         assert_quantity_allclose(spec_region['Subset 1'].subregions[0][0].value,
                                  1, atol=1e-5)
         assert_quantity_allclose(spec_region['Subset 1'].subregions[0][1].value,
@@ -191,10 +193,10 @@ class TestSpecvizHelper:
                                  7000*self.spec.spectral_axis.unit) +
                   SpectralRegion(7300*self.spec.spectral_axis.unit,
                                  7800*self.spec.spectral_axis.unit))
-        self.spec_app.plugins['Subset Tools']._obj.import_region(
+        self.spec_app.plugins['Subset Tools'].import_region(
             subset, combination_mode=['new', 'andnot', 'and'])
 
-        spec_region = self.spec_app.get_spectral_regions()
+        spec_region = self.spec_app.plugins['Subset Tools'].get_regions()
 
         assert len(spec_region['Subset 1'].subregions) == 1
         # Assert correct values for test with 3 subregions
@@ -210,10 +212,10 @@ class TestSpecvizHelper:
                                  6600*self.spec.spectral_axis.unit) +
                   SpectralRegion(7300*self.spec.spectral_axis.unit,
                                  7700*self.spec.spectral_axis.unit))
-        self.spec_app.plugins['Subset Tools']._obj.import_region(
+        self.spec_app.plugins['Subset Tools'].import_region(
             subset, combination_mode=['new', 'andnot', 'andnot'])
 
-        spec_region = self.spec_app.get_spectral_regions()
+        spec_region = self.spec_app.plugins['Subset Tools'].get_regions()
 
         assert len(spec_region['Subset 1'].subregions) == 3
         # Assert correct values for test with 3 subregions
@@ -261,7 +263,7 @@ def test_add_spectrum_after_subset(specviz_helper, spectrum1d):
     specviz_helper.load_data(spectrum1d, data_label="test")
     subset = SpectralRegion(6200 * spectrum1d.spectral_axis.unit,
                             7000 * spectrum1d.spectral_axis.unit)
-    specviz_helper.plugins['Subset Tools']._obj.import_region(subset)
+    specviz_helper.plugins['Subset Tools'].import_region(subset)
 
     new_spec = specviz_helper.get_spectra(apply_slider_redshift=True)["test"]*0.9
     specviz_helper.load_data(new_spec, data_label="test2")
@@ -272,9 +274,9 @@ def test_get_spectral_regions_unit(specviz_helper, spectrum1d):
     specviz_helper.load_data(spectrum1d)
     subset = SpectralRegion(6200 * spectrum1d.spectral_axis.unit,
                             7000 * spectrum1d.spectral_axis.unit)
-    specviz_helper.plugins['Subset Tools']._obj.import_region(subset)
+    specviz_helper.plugins['Subset Tools'].import_region(subset)
 
-    subsets = specviz_helper.get_spectral_regions()
+    subsets = specviz_helper.plugins['Subset Tools'].get_regions()
     reg = subsets.get('Subset 1')
 
     assert spectrum1d.spectral_axis.unit == reg.lower.unit
@@ -314,16 +316,16 @@ def test_get_spectral_regions_unit_conversion(specviz_helper, spectrum1d):
     specviz_helper.plugins['Unit Conversion'].spectral_unit = new_spectral_axis
     spectral_axis_unit = u.Unit(specviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
     subset = SpectralRegion(0.6 * spectral_axis_unit, 0.7 * spectral_axis_unit)
-    specviz_helper.plugins['Subset Tools']._obj.import_region(subset)
+    specviz_helper.plugins['Subset Tools'].import_region(subset)
 
     # Retrieve the Subset
-    subsets = specviz_helper.get_spectral_regions(use_display_units=False)
-    reg = subsets.get('Subset 1')
+    ss = specviz_helper.plugins['Subset Tools'].get_regions(use_display_units=False)
+    reg = ss.get('Subset 1')
     assert reg.lower.unit == u.Angstrom
     assert reg.upper.unit == u.Angstrom
 
-    subsets = specviz_helper.get_spectral_regions(use_display_units=True)
-    reg = subsets.get('Subset 1')
+    ss = specviz_helper.plugins['Subset Tools'].get_regions(use_display_units=True)
+    reg = ss.get('Subset 1')
     assert reg.lower.unit == u.um
     assert reg.upper.unit == u.um
 
@@ -349,7 +351,7 @@ def test_subset_default_thickness(specviz_helper, spectrum1d):
     spectral_axis_unit = u.Unit(specviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
     subset = SpectralRegion(2.5 * spectral_axis_unit,
                             3.5 * spectral_axis_unit)
-    specviz_helper.plugins['Subset Tools']._obj.import_region(subset)
+    specviz_helper.plugins['Subset Tools'].import_region(subset)
     # _on_layers_update is not triggered within CI
     sv._on_layers_update()
     assert sv.state.layers[-1].linewidth == 3
@@ -405,6 +407,27 @@ def test_load_spectrum_list_directory_concat(tmpdir, specviz_helper):
     assert len(specviz_helper.app.data_collection) == 41
 
 
+def test_load_2d_flux(specviz_helper):
+    # Test loading a spectrum with a 2D flux, which should be split into separate
+    # 1D Spectrum1D objects to load in Specviz.
+    spec = Spectrum1D(spectral_axis=np.linspace(4000, 6000, 10)*u.Angstrom,
+                      flux=np.ones((4, 10))*u.Unit("1e-17 erg / (Angstrom cm2 s)"))
+    specviz_helper.load_data(spec, data_label="test")
+
+    assert len(specviz_helper.app.data_collection) == 4
+    assert specviz_helper.app.data_collection[0].label == "test [0]"
+
+    spec2 = Spectrum1D(spectral_axis=np.linspace(4000, 6000, 10)*u.Angstrom,
+                       flux=np.ones((2, 10))*u.Unit("1e-17 erg / (Angstrom cm2 s)"))
+
+    # Make sure 2D spectra in a SpectrumList also get split properly.
+    spec_list = SpectrumList([spec, spec2])
+    specviz_helper.load_data(spec_list, data_label="second test")
+
+    assert len(specviz_helper.app.data_collection) == 10
+    assert specviz_helper.app.data_collection[-1].label == "second test [5]"
+
+
 def test_plot_uncertainties(specviz_helper, spectrum1d):
     specviz_helper.load_data(spectrum1d)
 
@@ -492,7 +515,7 @@ def test_delete_data_with_subsets(specviz_helper, spectrum1d, spectrum1d_nm):
 
     subset = SpectralRegion(6200 * spectral_axis_unit,
                             7000 * spectral_axis_unit)
-    specviz_helper.plugins['Subset Tools']._obj.import_region(subset)
+    specviz_helper.plugins['Subset Tools'].import_region(subset)
 
     assert len(specviz_helper.app.data_collection.subset_groups) == 1
     subset1 = specviz_helper.app.data_collection.subset_groups[0]
