@@ -3,6 +3,7 @@
 # get picked up when running the tests inside an interpreter using
 # packagename.test
 
+import os
 import warnings
 
 import numpy as np
@@ -13,7 +14,13 @@ from astropy.nddata import CCDData, StdDevUncertainty
 from astropy.wcs import WCS
 from specutils import Spectrum1D, SpectrumCollection, SpectrumList
 
-from jdaviz import __version__, Cubeviz, Imviz, Mosviz, Specviz, Specviz2d
+from jdaviz import __version__, Cubeviz, Imviz, Mosviz, Specviz, Specviz2d, Rampviz
+from jdaviz.configs.imviz.tests.utils import create_wfi_image_model
+from jdaviz.configs.imviz.plugins.parsers import HAS_ROMAN_DATAMODELS
+from jdaviz.utils import NUMPY_LT_2_0
+
+if not NUMPY_LT_2_0:
+    np.set_printoptions(legacy="1.25")
 
 SPECTRUM_SIZE = 10  # length of spectrum
 
@@ -43,6 +50,55 @@ def specviz2d_helper():
     return Specviz2d()
 
 
+@pytest.fixture
+def rampviz_helper():
+    return Rampviz()
+
+
+@pytest.fixture
+def roman_level_1_ramp():
+    from roman_datamodels.maker_utils import mk_datamodel
+    from roman_datamodels.datamodels import RampModel
+    rng = np.random.default_rng(seed=42)
+
+    shape = (10, 25, 25)
+    data_model = mk_datamodel(RampModel, shape=shape, dq=False)
+
+    data_model.data = 100 + 3 * np.cumsum(rng.uniform(size=shape), axis=0)
+    return data_model
+
+
+def _make_jwst_ramp(shape=(1, 10, 25, 25)):
+    from stdatamodels.jwst.datamodels import Level1bModel
+
+    rng = np.random.default_rng(seed=42)
+
+    # JWST Level 1b ramp files have an additional preceding dimension
+    # compared with Roman. This dimension is the integration number
+    # in a sequence (if there's more than one in the visit).
+    data_model = Level1bModel(shape)
+    data_model.data = 100 + 3 * np.cumsum(rng.uniform(size=shape), axis=0)
+
+    return data_model
+
+
+@pytest.fixture
+def jwst_level_1b_ramp():
+    return _make_jwst_ramp()
+
+
+@pytest.fixture
+def jwst_level_1b_rectangular_ramp():
+    return _make_jwst_ramp(shape=(1, 10, 32, 25))
+
+
+@pytest.fixture
+def jwst_level_2c_rate_image():
+    flux_hdu = fits.ImageHDU(np.ones((32, 25)))
+    flux_hdu.name = 'FLUX'
+    return fits.HDUList([fits.PrimaryHDU(), flux_hdu])
+
+
 @pytest.fixture
 def image_2d_wcs():
     return WCS({'CTYPE1': 'RA---TAN', 'CUNIT1': 'deg', 'CDELT1': -0.0002777777778,
@@ -93,7 +149,11 @@ def image_cube_hdu_obj():
 
 @pytest.fixture
 def image_cube_hdu_obj_microns():
-    flux_hdu = fits.ImageHDU(np.ones((8, 9, 10)).astype(np.float32))
+    # Basic rectangle ramp for aperture photometry test.
+    a = np.zeros((8, 9, 10)).astype(np.float32)  # (nz, ny, nx)
+    for i in range(8):
+        a[i, :5, :3] = i + 1
+    flux_hdu = fits.ImageHDU(a)
     flux_hdu.name = 'FLUX'
 
     uncert_hdu = fits.ImageHDU(np.zeros((8, 9, 10)).astype(np.float32))
@@ -133,11 +193,14 @@ def spectrum1d_cube_wcs():
     return wcs
 
 
-@pytest.fixture
-def spectrum1d():
+def _create_spectrum1d_with_spectral_unit(spectralunit=u.AA):
     np.random.seed(42)
 
+    # We make this first so we don't have to worry about inputting different bounds
     spec_axis = np.linspace(6000, 8000, SPECTRUM_SIZE) * u.AA
+    if spectralunit != u.AA:
+        spec_axis = spec_axis.to(spectralunit)
+
     flux = (np.random.randn(len(spec_axis.value)) +
             10*np.exp(-0.001*(spec_axis.value-6563)**2) +
             spec_axis.value/500) * u.Jy
@@ -148,6 +211,16 @@ def spectrum1d():
     return Spectrum1D(spectral_axis=spec_axis, flux=flux, uncertainty=uncertainty, meta=meta)
 
 
+@pytest.fixture
+def spectrum1d():
+    return _create_spectrum1d_with_spectral_unit()
+
+
+@pytest.fixture
+def spectrum1d_nm():
+    return _create_spectrum1d_with_spectral_unit(u.nm)
+
+
 @pytest.fixture
 def spectrum_collection(spectrum1d):
     sc = [spectrum1d] * 5
@@ -179,16 +252,25 @@ def multi_order_spectrum_list(spectrum1d, spectral_orders=10):
     return SpectrumList(sc)
 
 
-def _create_spectrum1d_cube_with_fluxunit(fluxunit=u.Jy, shape=(2, 2, 4)):
-
+def _create_spectrum1d_cube_with_fluxunit(fluxunit=u.Jy, shape=(2, 2, 4), with_uncerts=False):
+    # nz=2 nx=2 ny=4
     flux = np.arange(np.prod(shape)).reshape(shape) * fluxunit
     wcs_dict = {"CTYPE1": "RA---TAN", "CTYPE2": "DEC--TAN", "CTYPE3": "WAVE-LOG",
                 "CRVAL1": 205, "CRVAL2": 27, "CRVAL3": 4.622e-7,
                 "CDELT1": -0.0001, "CDELT2": 0.0001, "CDELT3": 8e-11,
-                "CRPIX1": 0, "CRPIX2": 0, "CRPIX3": 0}
+                "CRPIX1": 0, "CRPIX2": 0, "CRPIX3": 0,
+                # Need these for aperture photometry test.
+                "TELESCOP": "JWST", "BUNIT": fluxunit.to_string(), "PIXAR_A2": 0.01}
     w = WCS(wcs_dict)
+    if with_uncerts:
+        uncert = StdDevUncertainty(np.abs(np.random.normal(flux) * fluxunit))
 
-    return Spectrum1D(flux=flux, wcs=w)
+        return Spectrum1D(flux=flux,
+                          uncertainty=uncert,
+                          wcs=w,
+                          meta=wcs_dict)
+    else:
+        return Spectrum1D(flux=flux, wcs=w, meta=wcs_dict)
 
 
 @pytest.fixture
@@ -196,18 +278,48 @@ def spectrum1d_cube():
     return _create_spectrum1d_cube_with_fluxunit(fluxunit=u.Jy)
 
 
+@pytest.fixture
+def spectrum1d_cube_with_uncerts():
+    return _create_spectrum1d_cube_with_fluxunit(fluxunit=u.Jy, with_uncerts=True)
+
+
 @pytest.fixture
 def spectrum1d_cube_larger():
     return _create_spectrum1d_cube_with_fluxunit(fluxunit=u.Jy, shape=(SPECTRUM_SIZE, 2, 4))
 
 
+@pytest.fixture
+def spectrum1d_cube_largest():
+    wcs_dict = {"CTYPE1": "WAVE-LOG", "CTYPE2": "DEC--TAN", "CTYPE3": "RA---TAN",
+                "CRVAL1": 4.622e-7, "CRVAL2": 27, "CRVAL3": 205,
+                "CDELT1": 8e-11, "CDELT2": 0.0001, "CDELT3": -0.0001,
+                "CRPIX1": 0, "CRPIX2": 0, "CRPIX3": 0}
+    w = WCS(wcs_dict)
+    flux = np.zeros((20, 30, 3001), dtype=np.float32)  # nx=20 ny=30 nz=3001
+    flux[1:11, 5:15, :] = 1  # Bright corner
+    return Spectrum1D(flux=flux * u.Jy, wcs=w, meta=wcs_dict)
+
+
 @pytest.fixture
 def spectrum1d_cube_custom_fluxunit():
     return _create_spectrum1d_cube_with_fluxunit
 
 
 @pytest.fixture
-def mos_spectrum1d():
+def spectrum1d_cube_fluxunit_jy_per_steradian():
+    return _create_spectrum1d_cube_with_fluxunit(fluxunit=u.Jy/u.sr, shape=(10, 4, 5),
+                                                 with_uncerts=True)
+
+
+@pytest.fixture
+def spectrum1d_cube_sb_unit():
+    # similar fixture to spectrum1d_cube_fluxunit_jy_per_steradian, but no uncerts
+    # and different shape. can probably remove one of these eventually
+    return _create_spectrum1d_cube_with_fluxunit(fluxunit=u.Jy / u.sr)
+
+
+@pytest.fixture
+def mos_spectrum1d(mos_spectrum2d):
     '''
     A specially defined Spectrum1d that matches the corresponding spectrum2d below.
 
@@ -217,7 +329,7 @@ def mos_spectrum1d():
 
     Unless linking the two is required, try to use the global spectrum1d fixture.
     '''
-    spec_axis = np.linspace(6000, 8000, 1024) * u.AA
+    spec_axis = mos_spectrum2d.spectral_axis
     np.random.seed(42)
     flux = (np.random.randn(len(spec_axis.value)) +
             10*np.exp(-0.001*(spec_axis.value-6563)**2) +
@@ -238,6 +350,20 @@ def spectrum2d():
     return Spectrum1D(flux=data*u.MJy, spectral_axis=data[3]*u.um)
 
 
+def _generate_mos_spectrum2d():
+    header = {
+        'WCSAXES': 2,
+        'CRPIX1': 0.0, 'CRPIX2': 1024.5,
+        'CDELT1': 1E-06, 'CDELT2': 2.9256727777778E-05,
+        'CUNIT1': 'm', 'CUNIT2': 'deg',
+        'CTYPE1': 'WAVE', 'CTYPE2': 'OFFSET',
+        'CRVAL1': 0.0, 'CRVAL2': 5.0,
+        'RADESYS': 'ICRS', 'SPECSYS': 'BARYCENT'}
+    np.random.seed(42)
+    data = np.random.sample((1024, 15)) * u.one
+    return data, header
+
+
 @pytest.fixture
 def mos_spectrum2d():
     '''
@@ -247,20 +373,28 @@ def mos_spectrum2d():
     TODO: This should be reformed to match the global Spectrum1D defined above so that we may
     deprecate the mos-specific spectrum1d.
     '''
-    header = {
-        'WCSAXES': 2,
-        'CRPIX1': 0.0, 'CRPIX2': 1024.5,
-        'CDELT1': 1E-06, 'CDELT2': 2.9256727777778E-05,
-        'CUNIT1': 'm', 'CUNIT2': 'deg',
-        'CTYPE1': 'WAVE', 'CTYPE2': 'OFFSET',
-        'CRVAL1': 0.0, 'CRVAL2': 5.0,
-        'RADESYS': 'ICRS', 'SPECSYS': 'BARYCENT'}
+    data, header = _generate_mos_spectrum2d()
     wcs = WCS(header)
-    np.random.seed(42)
-    data = np.random.sample((1024, 15)) * u.one
     return Spectrum1D(data, wcs=wcs, meta=header)
 
 
+@pytest.fixture
+def mos_spectrum2d_as_hdulist():
+    data, header = _generate_mos_spectrum2d()
+    hdu = fits.ImageHDU(data.value)
+    hdu.header.update(header)
+
+    # This layout is to trick specutils to think it is JWST s2d
+    hdulist = fits.HDUList([fits.PrimaryHDU(), hdu, hdu])
+    hdulist[0].header["TELESCOP"] = "JWST"
+    hdulist[1].name = "SCI"
+    hdulist[1].ver = 1
+    hdulist[2].name = "SCI"
+    hdulist[2].ver = 2
+
+    return hdulist
+
+
 @pytest.fixture
 def mos_image():
     header = {
@@ -279,6 +413,24 @@ def mos_image():
     return CCDData(data, wcs=wcs, unit='Jy', meta=header)
 
 
+@pytest.fixture
+def roman_imagemodel():
+    if HAS_ROMAN_DATAMODELS:
+        return create_wfi_image_model((20, 10))
+
+
+# Copied over from https://github.com/spacetelescope/ci_watson
+@pytest.fixture(scope='function')
+def _jail(tmp_path):
+    """Perform test in a pristine temporary working directory."""
+    old_dir = os.getcwd()
+    os.chdir(tmp_path)
+    try:
+        yield str(tmp_path)
+    finally:
+        os.chdir(old_dir)
+
+
 try:
     from pytest_astropy_header.display import PYTEST_HEADER_MODULES, TESTED_VERSIONS
 except ImportError:
@@ -305,10 +457,12 @@ def pytest_configure(config):
     PYTEST_HEADER_MODULES['ipyvuetify'] = 'ipyvuetify'
     PYTEST_HEADER_MODULES['ipysplitpanes'] = 'ipysplitpanes'
     PYTEST_HEADER_MODULES['ipygoldenlayout'] = 'ipygoldenlayout'
-    PYTEST_HEADER_MODULES['voila'] = 'voila'
+    PYTEST_HEADER_MODULES['ipypopout'] = 'ipypopout'
+    PYTEST_HEADER_MODULES['solara'] = 'solara'
     PYTEST_HEADER_MODULES['vispy'] = 'vispy'
     PYTEST_HEADER_MODULES['gwcs'] = 'gwcs'
     PYTEST_HEADER_MODULES['asdf'] = 'asdf'
     PYTEST_HEADER_MODULES['stdatamodels'] = 'stdatamodels'
+    PYTEST_HEADER_MODULES['roman_datamodels'] = 'roman_datamodels'
 
     TESTED_VERSIONS['jdaviz'] = __version__
