@@ -1,3 +1,5 @@
+import os
+
 import gwcs
 import numpy as np
 from astropy import units as u
@@ -7,9 +9,8 @@ from echo import delay_callback
 from glue.config import colormaps
 from glue.core import Data
 
-from jdaviz.configs.imviz.helper import get_top_layer_index
-from jdaviz.core.events import SnackbarMessage, MarkersChangedMessage
-from jdaviz.core.helpers import data_has_valid_wcs
+from jdaviz.utils import get_top_layer_index, get_reference_image_data, data_has_valid_wcs
+from jdaviz.core.events import SnackbarMessage, AstrowidgetMarkersChangedMessage
 
 __all__ = ['AstrowidgetsImageViewerMixin']
 
@@ -37,10 +38,24 @@ class AstrowidgetsImageViewerMixin:
         self.marker = {'color': 'red', 'alpha': 1.0, 'markersize': 5}
 
     def save(self, filename):
-        """Save out the current image view to given PNG filename."""
+        """Save out the current image view to given PNG filename.
+
+        Parameters
+        ----------
+        filename : str
+            PNG filename. If the given file already exists, it will be
+            silently overwritten.
+
+        """
         if not filename.lower().endswith('.png'):
             filename = filename + '.png'
-        self.figure.save_png(filename=filename)
+
+        # https://github.com/bqplot/bqplot/pull/1397
+        def on_png_received(data):
+            with open(os.path.expanduser(filename), 'bw') as f:
+                f.write(data)
+
+        self.figure.get_png_data(on_png_received)
 
     def center_on(self, point):
         """Centers the view on a particular point on the top visible layer.
@@ -61,6 +76,9 @@ class AstrowidgetsImageViewerMixin:
 
         """
         i_top = get_top_layer_index(self)
+        if i_top is None:
+            return
+
         image = self.layers[i_top].layer
 
         if isinstance(point, SkyCoord):
@@ -85,12 +103,12 @@ class AstrowidgetsImageViewerMixin:
 
         width = self.state.x_max - self.state.x_min
         height = self.state.y_max - self.state.y_min
+        new_xmin = pix[0] - (width * 0.5)
+        new_ymin = pix[1] - (height * 0.5)
 
-        with delay_callback(self.state, 'x_min', 'x_max', 'y_min', 'y_max'):
-            self.state.x_min = pix[0] - (width * 0.5)
-            self.state.y_min = pix[1] - (height * 0.5)
-            self.state.x_max = self.state.x_min + width
-            self.state.y_max = self.state.y_min + height
+        self.set_limits(
+            x_min=new_xmin, x_max=new_xmin + width,
+            y_min=new_ymin, y_max=new_ymin + height)
 
     def offset_by(self, dx, dy):
         """Move the center to a point that is given offset
@@ -115,8 +133,16 @@ class AstrowidgetsImageViewerMixin:
             Sky offset has invalid unit.
 
         """
+        i_top = get_top_layer_index(self)
+        image = self.layers[i_top].layer
         width = self.state.x_max - self.state.x_min
         height = self.state.y_max - self.state.y_min
+        x_cen = self.state.x_min + (width * 0.5)
+        y_cen = self.state.y_min + (height * 0.5)
+        if hasattr(self, '_get_real_xy'):
+            real_cen = self._get_real_xy(image, x_cen, y_cen)
+        else:
+            real_cen = (x_cen, y_cen)
 
         dx, dx_coord = _offset_is_pixel_or_sky(dx)
         dy, dy_coord = _offset_is_pixel_or_sky(dy)
@@ -125,28 +151,26 @@ class AstrowidgetsImageViewerMixin:
             raise ValueError(f'dx is of type {dx_coord} but dy is of type {dy_coord}')
 
         if dx_coord == 'wcs':
-            i_top = get_top_layer_index(self)
-            image = self.layers[i_top].layer
             if data_has_valid_wcs(image):
                 # To avoid distortion headache, assume offset is relative to
                 # displayed center.
-                x_cen = self.state.x_min + (width * 0.5)
-                y_cen = self.state.y_min + (height * 0.5)
-                sky_cen = image.coords.pixel_to_world(x_cen, y_cen)
-                new_sky_cen = sky_cen.spherical_offsets_by(dx, dy)
-                self.center_on(new_sky_cen)
+                sky_cen = image.coords.pixel_to_world(real_cen[0], real_cen[1])
+                new_cen = sky_cen.spherical_offsets_by(dx, dy)
             else:
                 raise AttributeError(f'{getattr(image, "label", None)} does not have a valid WCS')
         else:
-            with delay_callback(self.state, 'x_min', 'x_max', 'y_min', 'y_max'):
-                self.state.x_min += dx
-                self.state.y_min += dy
-                self.state.x_max = self.state.x_min + width
-                self.state.y_max = self.state.y_min + height
+            new_cen = (real_cen[0] + dx, real_cen[1] + dy)
+
+        self.center_on(new_cen)
 
     @property
     def zoom_level(self):
-        """Zoom level:
+        """
+        The zoom level for an image viewer (not linked by WCS).
+
+        .. warning::
+            When a viewer is linked by WCS, the result corresponds
+            to the ``zoom_level`` of the reference data.
 
         * 1 means real-pixel-size.
         * 2 means zoomed in by a factor of 2.
@@ -157,10 +181,20 @@ class AstrowidgetsImageViewerMixin:
         if self.shape is None:  # pragma: no cover
             raise ValueError('Viewer is still loading, try again later')
 
+        if hasattr(self, '_get_real_xy'):
+            image, i_ref = get_reference_image_data(self.jdaviz_app, self.reference)
+            # TODO: Do we want top layer instead?
+            # i_top = get_top_layer_index(self)
+            # image = self.layers[i_top].layer
+            real_min = self._get_real_xy(image, self.state.x_min, self.state.y_min)
+            real_max = self._get_real_xy(image, self.state.x_max, self.state.y_max)
+        else:
+            real_min = (self.state.x_min, self.state.y_min)
+            real_max = (self.state.x_max, self.state.y_max)
         screenx = self.shape[1]
         screeny = self.shape[0]
-        zoom_x = screenx / (self.state.x_max - self.state.x_min)
-        zoom_y = screeny / (self.state.y_max - self.state.y_min)
+        zoom_x = screenx / abs(real_max[0] - real_min[0])
+        zoom_y = screeny / abs(real_max[1] - real_min[1])
 
         return max(zoom_x, zoom_y)  # Similar to Ginga get_scale()
 
@@ -171,8 +205,7 @@ class AstrowidgetsImageViewerMixin:
                 (isinstance(val, (int, float)) and val <= 0)):
             raise ValueError(f'Unsupported zoom level: {val}')
 
-        image = self.state.reference_data
-        if (image is None or self.shape is None or
+        if (self.shape is None or
                 self.state.x_att is None or self.state.y_att is None):  # pragma: no cover
             return
 
@@ -180,15 +213,26 @@ class AstrowidgetsImageViewerMixin:
         if val == 'fit':
             self.state.reset_limits()
             return
+
+        new_dx = self.shape[1] * 0.5 / val
+        if hasattr(self, '_get_real_xy'):
+            image, i_ref = get_reference_image_data(self.jdaviz_app, self.reference)
+            # TODO: Do we want top layer instead?
+            # i_top = get_top_layer_index(self)
+            # image = self.layers[i_top].layer
+            real_min = self._get_real_xy(image, self.state.x_min, self.state.y_min)
+            real_max = self._get_real_xy(image, self.state.x_max, self.state.y_max)
+            cur_xcen = (real_min[0] + real_max[0]) * 0.5
+            new_x_min = self._get_real_xy(image, cur_xcen - new_dx - 0.5, real_min[1], reverse=True)[0]  # noqa: E501
+            new_x_max = self._get_real_xy(image, cur_xcen + new_dx - 0.5, real_max[1], reverse=True)[0]  # noqa: E501
         else:
             cur_xcen = (self.state.x_min + self.state.x_max) * 0.5
-            new_dx = self.shape[1] * 0.5 / val
-            new_x_min = cur_xcen - new_dx
-            new_x_max = cur_xcen + new_dx
+            new_x_min = cur_xcen - new_dx - 0.5
+            new_x_max = cur_xcen + new_dx - 0.5
 
         with delay_callback(self.state, 'x_min', 'x_max'):
-            self.state.x_min = new_x_min - 0.5
-            self.state.x_max = new_x_max - 0.5
+            self.state.x_min = new_x_min
+            self.state.x_max = new_x_max
 
         # We need to adjust the limits in here to avoid triggering all
         # the update events then changing the limits again.
@@ -199,6 +243,10 @@ class AstrowidgetsImageViewerMixin:
     def zoom(self, val):
         """Zoom in or out by the given factor.
 
+        .. warning::
+            When a viewer is linked by WCS, this method accidentally
+            changes the center also; see the warning in ``zoom_level``.
+
         Parameters
         ----------
         val : int or float
@@ -346,7 +394,7 @@ class AstrowidgetsImageViewerMixin:
             {'color': (1, 0, 0)}
 
         The valid properties for Glue markers are listed at
-        https://docs.glueviz.org/en/stable/api/glue.core.visual.VisualAttributes.html
+        https://glue-core.readthedocs.io/en/latest/api/glue.core.visual.VisualAttributes.html
 
         """
         return self._marker_dict
@@ -427,7 +475,7 @@ class AstrowidgetsImageViewerMixin:
             Invalid marker name.
 
         """
-        from glue_jupyter.bqplot.scatter.layer_artist import BqplotScatterLayerState
+        from glue.viewers.scatter.state import ScatterLayerState
 
         if marker_name is None:
             marker_name = self._default_mark_tag_name
@@ -435,8 +483,12 @@ class AstrowidgetsImageViewerMixin:
         self._validate_marker_name(marker_name)
         jglue = self.session.application
 
-        # Link markers to reference image data.
-        image = self.state.reference_data
+        # Link markers to top visible image data or reference data.
+        if not use_skycoord and hasattr(self, '_get_real_xy'):
+            i_top = get_top_layer_index(self)
+            image = self.layers[i_top].layer
+        else:
+            image = self.state.reference_data
 
         # TODO: Is Glue smart enough to no-op if link already there?
         if use_skycoord:
@@ -474,7 +526,7 @@ class AstrowidgetsImageViewerMixin:
             # Only can set alpha and color using self.add_data(), so brute force here instead.
             # https://github.com/glue-viz/glue/issues/2201
             for lyr in self.state.layers:
-                if isinstance(lyr, BqplotScatterLayerState) and lyr.layer.label == marker_name:
+                if isinstance(lyr, ScatterLayerState) and lyr.layer.label == marker_name:
                     for key, val in self.marker.items():
                         setattr(lyr, {'markersize': 'size'}.get(key, key), val)
                     break
@@ -484,7 +536,7 @@ class AstrowidgetsImageViewerMixin:
 
             self._marktags.add(marker_name)
 
-            self.session.hub.broadcast(MarkersChangedMessage(True, sender=self))
+            self.session.hub.broadcast(AstrowidgetMarkersChangedMessage(True, sender=self))
 
     def remove_markers(self, marker_name=None):
         """Remove some but not all of the markers by name used when
@@ -519,7 +571,8 @@ class AstrowidgetsImageViewerMixin:
         self.session.application.data_collection.remove(data)
         self._marktags.remove(marker_name)
 
-        self.session.hub.broadcast(MarkersChangedMessage(len(self._marktags) > 0, sender=self))
+        self.session.hub.broadcast(AstrowidgetMarkersChangedMessage(len(self._marktags) > 0,
+                                                                    sender=self))
 
     def reset_markers(self):
         """Delete all markers."""
