@@ -2,11 +2,12 @@ from contextlib import contextmanager
 from echo import delay_callback, CallbackProperty
 import numpy as np
 
+from astropy import units as u
 from glue.viewers.profile.state import ProfileViewerState
 from glue_jupyter.bqplot.image.state import BqplotImageViewerState
 from glue.viewers.matplotlib.state import DeferredDrawCallbackProperty as DDCProperty
 
-from jdaviz.utils import get_reference_image_data
+from jdaviz.utils import get_reference_image_data, flux_conversion
 
 __all__ = ['FreezableState', 'FreezableProfileViewerState', 'FreezableBqplotImageViewerState']
 
@@ -53,6 +54,37 @@ class FreezableProfileViewerState(ProfileViewerState, FreezableState):
             self.x_min = x_min
             self.x_max = x_max
 
+    def _convert_units_y_limits(self, old_unit, new_unit):
+        # override glue's _convert_units_y_limits to account
+        # for equivalencies.  This converts all four corners
+        # of the limits to set new limits that contain those
+        # same corners
+
+        if old_unit != new_unit:
+            if old_unit is None or new_unit is None:
+                self._reset_y_limits()
+                return
+            x_corners = np.array([self.x_min, self.x_min, self.x_max, self.x_max])
+            y_corners = np.array([self.y_min, self.y_max, self.y_min, self.y_max])
+            spectral_axis = x_corners * u.Unit(self.x_display_unit)
+
+            # NOTE: this uses the scale factor from the first found layer.  We may want to
+            # generalize this to iterate over all scale factors if/when we support multiple
+            # flux cubes (with potentially different pixel scale factors).
+            for layer in self.layers:
+                if psc := getattr(layer.layer, 'meta', {}).get('_pixel_scale_factor', None):  # noqa
+                    spectral_axis.info.meta = {'_pixel_scale_factor',
+                                               psc}
+                    break
+            else:
+                spectral_axis.info.meta = {}
+
+            y_corners_new = flux_conversion(y_corners, old_unit, new_unit, spectral_axis=spectral_axis)  # noqa
+
+            with delay_callback(self, 'y_min', 'y_max'):
+                self.y_min = np.nanmin(y_corners_new)
+                self.y_max = np.nanmax(y_corners_new)
+
 
 class FreezableBqplotImageViewerState(BqplotImageViewerState, FreezableState):
     linked_by_wcs = False
