@@ -19,8 +19,9 @@ from glue.core.subset import Subset, MaskSubsetState
 from glue.config import data_translator
 from ipywidgets.widgets import widget_serialization
 
-import astropy.units as u
 from astropy.nddata import NDDataArray, CCDData, StdDevUncertainty
+import astropy.units as u
+from astropy.utils.decorators import deprecated
 from regions.core.core import Region
 from specutils import Spectrum1D, SpectralRegion
 
@@ -136,17 +137,6 @@ class ConfigHelper(HubListener):
                    for item in self.app.state.tray_items if item['is_relevant']}
 
         # handle renamed plugins during deprecation
-        if 'Orientation' in plugins:
-            # renamed in 3.9
-            plugins['Links Control'] = plugins['Orientation']._obj.user_api
-            plugins['Links Control']._deprecation_msg = 'in the future, the formerly named \"Links Control\" plugin will only be available by its new name: \"Orientation\".'  # noqa
-        if 'Canvas Rotation' in plugins:
-            # removed in 3.9
-            plugins['Canvas Rotation']._deprecation_msg = 'this functionality will be removed in favor of the implementation for rotation in the \"Orientation\" plugin.'  # noqa
-        if 'Export' in plugins:
-            # renamed in 3.9
-            plugins['Export Plot'] = plugins['Export']._obj.user_api
-            plugins['Export Plot']._deprecation_msg = 'in the future, the formerly named \"Export Plot\" plugin will only be available by its new name: \"Export\".'  # noqa
         if 'Image Profiles (XY)' in plugins:
             # renamed in 4.0
             plugins['Imviz Line Profiles (XY)'] = plugins['Image Profiles (XY)']._obj.user_api
@@ -464,6 +454,20 @@ class ConfigHelper(HubListener):
                       DeprecationWarning)
         return self.show(loc="sidecar:tab-after", title=title)
 
+    def toggle_api_hints(self, enabled=None):
+        """
+        Toggle the visibility of API hints in the application.
+
+        Parameters
+        ----------
+        enabled : bool, optional
+            If `True`, show API hints. If `False`, hide API hints.
+            If `None`, toggle the current state.
+        """
+        if enabled is None:
+            enabled = not self.app.state.show_api_hints
+        self.app.state.show_api_hints = enabled
+
     def _handle_display_units(self, data, use_display_units=True):
         if use_display_units:
             if isinstance(data, Spectrum1D):
@@ -889,8 +893,10 @@ class ImageConfigHelper(ConfigHelper):
         if return_bad_regions:
             return bad_regions
 
+    @deprecated(since="4.1", alternative="subset_tools.get_regions")
     def get_interactive_regions(self):
-        """Return spatial regions that can be interacted with in the viewer.
+        """
+        Return spatial regions that can be interacted with in the viewer.
         This does not return masked regions added via :meth:`load_regions`.
 
         Unsupported region shapes will be skipped. When that happens,
