@@ -40,7 +40,10 @@ class _BaseZoomHistory:
     # Mixin for custom zoom tools to be able to save their previous zoom state
     # which is then used by the PrevZoom tool
     def save_prev_zoom(self):
-        self.viewer._prev_limits = self.viewer.get_limits()
+        # Cannot use viewer.get_limits() here because viewers from
+        # glue-jupyter does not have that method.
+        self.viewer._prev_limits = (self.viewer.state.x_min, self.viewer.state.x_max,
+                                    self.viewer.state.y_min, self.viewer.state.y_max)
 
 
 class _MatchedZoomMixin:
@@ -555,10 +558,10 @@ class SinglePixelRegion(CheckableTool):
 
         if data['altKey'] is True:
             reg = self.get_subset(x, y, as_roi=False)
-            self.viewer.jdaviz_app.get_tray_item_from_name('g-subset-plugin').combination_mode.selected = 'new'  # noqa
-            self.viewer.jdaviz_app.get_tray_item_from_name('g-subset-plugin').import_region(
+            self.viewer.jdaviz_app.get_tray_item_from_name('g-subset-tools').combination_mode.selected = 'new'  # noqa
+            self.viewer.jdaviz_app.get_tray_item_from_name('g-subset-tools').import_region(
                 reg, return_bad_regions=True)
-            self.viewer.jdaviz_app.get_tray_item_from_name('g-subset-plugin').combination_mode.selected = 'replace'  # noqa
+            self.viewer.jdaviz_app.get_tray_item_from_name('g-subset-tools').combination_mode.selected = 'replace'  # noqa
 
         else:
             roi = self.get_subset(x, y, as_roi=True)
