@@ -14,23 +14,27 @@ from astropy.wcs.wcsapi import BaseHighLevelWCS
 from astropy.units import Quantity
 from astropy import units as u
 from astroquery.mast import Observations, conf
+from matplotlib import colors as mpl_colors
+import matplotlib.cm as cm
+from photutils.utils import make_random_cmap
 
 from glue.config import settings
+from glue.config import colormaps as glue_colormaps
 from glue.core import BaseData
 from glue.core.exceptions import IncompatibleAttribute
 from glue.core.subset import SubsetState, RangeSubsetState, RoiSubsetState
 from glue_astronomy.spectral_coordinates import SpectralCoordinates
 from ipyvue import watch
 
-from jdaviz.core.custom_units import PIX2
-from jdaviz.core.validunits import check_if_unit_is_per_solid_angle
+from jdaviz.core.custom_units_and_equivs import PIX2, _eqv_pixar_sr, _eqv_flux_to_sb_pixel
+from jdaviz.core.unit_conversion_utils import check_if_unit_is_per_solid_angle
 
 __all__ = ['SnackbarQueue', 'enable_hot_reloading', 'bqplot_clear_figure',
            'standardize_metadata', 'ColorCycler', 'alpha_index', 'get_subset_type',
            'download_uri_to_path', 'flux_conversion', 'spectral_axis_conversion',
            'layer_is_2d', 'layer_is_2d_or_3d', 'layer_is_image_data', 'layer_is_wcs_only',
            'get_wcs_only_layer_labels', 'get_top_layer_index', 'get_reference_image_data',
-           'standardize_roman_metadata']
+           'standardize_roman_metadata', 'cmap_samples', 'glue_colormaps']
 
 NUMPY_LT_2_0 = not minversion("numpy", "2.0.dev")
 
@@ -322,7 +326,7 @@ def standardize_roman_metadata(data_model):
 
 
 def indirect_units():
-    from jdaviz.core.validunits import supported_sq_angle_units
+    from jdaviz.core.unit_conversion_utils import supported_sq_angle_units
 
     units = []
 
@@ -338,7 +342,7 @@ def indirect_units():
     return units
 
 
-def flux_conversion(values, original_units, target_units, spec=None, eqv=None, slice=None):
+def flux_conversion(values, original_units, target_units, spec=None, eqv=None, spectral_axis=None):
     """
     Convert flux or surface brightness values from original units to target units.
 
@@ -363,8 +367,8 @@ def flux_conversion(values, original_units, target_units, spec=None, eqv=None, s
     eqv : list of :ref:`astropy:unit_equivalencies`, optional
         A list of Astropy equivalencies necessary for complex unit conversions/translations.
 
-    slice : `astropy.units.Quantity`, optional
-        The current slice of a data cube, with units. Necessary for complex unit
+    spectral_axis : `astropy.units.Quantity`, optional
+        Provide spectral axis associated with values array. Necessary for simple and complex unit
         conversions/translations that require spectral density equivalencies.
 
     Returns
@@ -379,7 +383,7 @@ def flux_conversion(values, original_units, target_units, spec=None, eqv=None, s
     # If there are only two values, this is likely the limits being converted, so then
     # in case we need to use the spectral density equivalency, we need to provide only
     # to spectral axis values. If there is only one value
-    image_data = False
+    indirect_needs_spec_axis = False
     if spec:
         if not np.isscalar(values) and len(values) == 2:
             spectral_values = spec.spectral_axis[0]
@@ -394,10 +398,18 @@ def flux_conversion(values, original_units, target_units, spec=None, eqv=None, s
             eqv = u.spectral_density(spectral_values)
         else:
             eqv = u.spectral_density(spec.spectral_axis[0])
-    elif slice is not None and eqv:
-        image_data = True
-        # Need this to convert Flux to Flux for complex conversions/translations of cube image data
-        eqv += u.spectral_density(slice)
+    elif spectral_axis is not None:
+        if not isinstance(spectral_axis, u.Quantity):
+            raise TypeError("spectral_axis must be an instance of astropy.units.Quantity.")
+
+        if eqv:
+            indirect_needs_spec_axis = True
+            # Needed to convert Flux to Flux for complex conversion/translation of non-spectrum data
+            eqv += u.spectral_density(spectral_axis)
+        elif not np.isscalar(values) and len(values) != spectral_axis.size:
+            raise ValueError(f"Size mismatch: values size : ({values.size}) must match spectral_axis size : ({spectral_axis.size}).")  # noqa
+        else:
+            eqv = u.spectral_density(spectral_axis)
 
     orig_units = u.Unit(original_units)
     targ_units = u.Unit(target_units)
@@ -406,7 +418,9 @@ def flux_conversion(values, original_units, target_units, spec=None, eqv=None, s
     solid_angle_in_targ = check_if_unit_is_per_solid_angle(targ_units, return_unit=True)
 
     # Ensure a spectrum passed through Spectral Extraction plugin
-    if (((spec and ('_pixel_scale_factor' in spec.meta))) and
+    if ((((spec and ('_pixel_scale_factor' in spec.meta))) or
+        (spectral_axis is not None and ('_pixel_scale_factor' in spectral_axis.info.meta)))
+        and
             (((solid_angle_in_orig) and (not solid_angle_in_targ)) or
              ((not solid_angle_in_orig) and (solid_angle_in_targ)))):
         # Data item in data collection does not update from conversion/translation.
@@ -415,7 +429,13 @@ def flux_conversion(values, original_units, target_units, spec=None, eqv=None, s
         n_values = len(values)
 
         # Make sure they are float (can be Quantity).
-        fac = spec.meta['_pixel_scale_factor']
+        if spec:
+            fac = spec.meta['_pixel_scale_factor']
+        elif spectral_axis is not None:
+            # Quantity.info.meta gets casted to set
+            fac = next((item for item in spectral_axis.info.meta if isinstance(item, float)), None)
+            spec_unit = orig_units
+
         if isinstance(fac, Quantity):
             fac = fac.value
 
@@ -450,10 +470,10 @@ def flux_conversion(values, original_units, target_units, spec=None, eqv=None, s
             elif selected_unit_updated == 'orig':
                 orig_units = updated_units
 
-    elif image_data:
+    elif indirect_needs_spec_axis:
         values, orig_units = _indirect_conversion(
             values=values, orig_units=orig_units, targ_units=targ_units,
-            eqv=eqv, image_data=image_data
+            eqv=eqv, indirect_needs_spec_axis=indirect_needs_spec_axis
             )
     elif solid_angle_in_orig == solid_angle_in_targ == PIX2:
         # in the case where we have 2 SBs per solid pixel that need
@@ -469,7 +489,7 @@ def flux_conversion(values, original_units, target_units, spec=None, eqv=None, s
 
 
 def _indirect_conversion(values, orig_units, targ_units, eqv,
-                         spec_unit=None, image_data=None):
+                         spec_unit=None, indirect_needs_spec_axis=None):
 
     # Note: is there a way we could write this to not require 'spec_unit'? It
     # seems like it falls back on this to get a solid angle unit, but can we
@@ -498,9 +518,10 @@ def _indirect_conversion(values, orig_units, targ_units, eqv,
 
         return values, targ_units, 'targ'
 
-    elif image_data or (spec_unit and solid_angle_in_spec):
+    elif indirect_needs_spec_axis or (spec_unit and solid_angle_in_spec):
         if not solid_angle_in_targ:
             targ_units /= solid_angle_in_spec
+            solid_angle_in_targ = solid_angle_in_spec
         if ((u.Unit(targ_units) in indirect_units()) or
            (u.Unit(orig_units) in indirect_units())):
             # SB -> Flux -> Flux -> SB
@@ -519,70 +540,6 @@ def _indirect_conversion(values, orig_units, targ_units, eqv,
         return values, orig_units
 
 
-def _eqv_pixar_sr(pixar_sr):
-    """
-    Return Equivalencies to convert from flux to flux per solid
-    angle (aka surface brightness) using scale ratio `pixar_sr`
-    (steradians per pixel).
-    """
-    def converter_flux(x):  # Surface Brightness -> Flux
-        return x * pixar_sr
-
-    def iconverter_flux(x):  # Flux -> Surface Brightness
-        return x / pixar_sr
-
-    return [
-        (u.MJy / u.sr, u.MJy, converter_flux, iconverter_flux),
-        (u.erg / (u.s * u.cm**2 * u.Angstrom * u.sr), u.erg / (u.s * u.cm**2 * u.Angstrom), converter_flux, iconverter_flux),  # noqa
-        (u.ph / (u.Angstrom * u.s * u.cm**2 * u.sr), u.ph / (u.Angstrom * u.s * u.cm**2), converter_flux, iconverter_flux),  # noqa
-        (u.ph / (u.Hz * u.s * u.cm**2  * u.sr), u.ph / (u.Hz * u.s * u.cm**2), converter_flux, iconverter_flux),  # noqa
-        (u.ct / u.sr, u.ct, converter_flux, iconverter_flux)  # noqa
-    ]
-
-
-def _eqv_flux_to_sb_pixel():
-    """
-    Returns an Equivalency between `flux_unit` and `flux_unit`/pix**2. This
-    allows conversion between flux and flux-per-square-pixel surface brightness
-    e.g MJy <> MJy / pix2
-    """
-
-    # generate an equivalency for each flux type that would need
-    # another equivalency for converting to/from
-    flux_units = [u.MJy, u.erg / (u.s * u.cm**2 * u.Angstrom),
-                  u.ph / (u.Angstrom * u.s * u.cm**2),
-                  u.ph / (u.Hz * u.s * u.cm**2)]
-    return [(flux_unit, flux_unit / PIX2, lambda x: x, lambda x: x)
-            for flux_unit in flux_units]
-
-
-def _eqv_sb_per_pixel_to_per_angle(flux_unit, scale_factor=1):
-    """
-    Returns an equivalency between `flux_unit` per square pixel and
-    `flux_unit` per solid angle to be able to compare and convert between units
-    like Jy/pix**2 and Jy/sr. The scale factor is assumed to be in steradians,
-    to follow the convention of the PIXAR_SR keyword.
-    Note:
-    To allow conversions between units like 'ph / (Hz s cm2 sr)' and
-    MJy / pix2, which would require this equivalency as well as u.spectral_density,
-    these CAN'T be combined when converting like:
-    equivalencies=u.spectral_density(1 * u.m) + _eqv_sb_per_pixel_to_per_angle(u.Jy)
-    So additional logic is needed to compare units that need both equivalencies
-    (one solution being creating this equivalency for each equivalent flux-type.)
-
-    """
-
-    # the two types of units we want to define a conversion between
-    flux_solid_ang = flux_unit / u.sr
-    flux_sq_pix = flux_unit / PIX2
-
-    pix_to_solid_angle_equiv = [(flux_solid_ang, flux_sq_pix,
-                                lambda x: x * scale_factor,
-                                lambda x: x / scale_factor)]
-
-    return pix_to_solid_angle_equiv
-
-
 def spectral_axis_conversion(values, original_units, target_units):
     eqv = u.spectral() + u.pixel_scale(1*u.pix)
     return (values * u.Unit(original_units)).to_value(u.Unit(target_units), equivalencies=eqv)
@@ -929,3 +886,52 @@ def get_reference_image_data(app, viewer_id=None):
         return refdata, iref
 
     return None, -1
+
+
+# Add new and inverse colormaps to Glue global state. Also see ColormapRegistry in
+# https://github.com/glue-viz/glue/blob/main/glue/config.py
+new_cms = (['Rainbow', cm.rainbow],
+           ['Seismic', cm.seismic],
+           ['Reversed: Gray', cm.gray_r],
+           ['Reversed: Viridis', cm.viridis_r],
+           ['Reversed: Plasma', cm.plasma_r],
+           ['Reversed: Inferno', cm.inferno_r],
+           ['Reversed: Magma', cm.magma_r],
+           ['Reversed: Hot', cm.hot_r],
+           ['Reversed: Rainbow', cm.rainbow_r])
+for cur_cm in new_cms:
+    if cur_cm not in glue_colormaps.members:
+        glue_colormaps.add(*cur_cm)
+
+
+def _register_random_cmap(
+    cmap_name,
+    bkg_color=[0, 0, 0],
+    bkg_alpha=1,
+    seed=42,
+    ncolors=10_000
+):
+    """
+    Custom random colormap, useful for rendering image
+    segmentation maps. The default background for
+    `label==0` is *transparent*. If the segmentation map
+    contains more than 10,000 labels, adjust the `ncolors`
+    kwarg to ensure uniqueness.
+    """
+    cmap = make_random_cmap(ncolors=ncolors, seed=seed)
+    cmap.colors[0] = bkg_color + [bkg_alpha]
+    cmap.name = cmap_name
+    glue_colormaps.add(cmap_name, cmap)
+
+
+_register_random_cmap('Random', bkg_alpha=1)
+
+
+# give UI access to sampled version of the available colormap choices
+def _hex_for_cmap(cmap):
+    N = 50
+    cm_sampled = cmap.resampled(N)
+    return [mpl_colors.to_hex(cm_sampled(i)) for i in range(N)]
+
+
+cmap_samples = {cmap[1].name: _hex_for_cmap(cmap[1]) for cmap in glue_colormaps.members}
